@@ -3,7 +3,7 @@ License: GPLv2, read more from COPYING
 */
 #ifndef _CEM_H_
 #define _CEM_H_
-
+#include <glib.h>
 //Log-message types. Influenced by log4j-type levels.
 //J_LOG_TRACE   More detailed information.  //any use of this?
 enum {
@@ -24,5 +24,6 @@ void cem_set_log_level(int new_level);
 void cem_append_to_log_level(int level);
 void jammo_cem_cleanup();
 void cem_get_time(char timestamp_now[]);
+void cem_print_also_to_stdout(gboolean b);
 
 #endif  /* _CEM_H_ */
