@@ -245,11 +245,17 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 
 static gboolean initialization_needed = TRUE;
 
-void singinggame_force_reinit_songs(){
+void  singinggame_clean_songlist() {
 	if (songs){ //songs is static GList
+		cem_add_to_log("Cleaning singing game song list", J_LOG_DEBUG);
 		g_list_foreach (songs,(GFunc)song_free,NULL);
 		g_list_free(songs);
 	}
+}
+
+void singinggame_force_reinit_songs(){
+	singinggame_clean_songlist();
+
 	songs = song_init_songs_from_disk();
 	clutter_actor_hide(jammo_get_actor_by_id("wait"));
 	initialization_needed = TRUE;
