@@ -575,7 +575,7 @@ GList* song_init_songs_from_disk(){
 		{
 		//There will be more optional folders. TODO
 		
-		gchar* base_path=""; //this is where we try found songs
+		gchar* base_path=NULL; //this is where we try found songs
 		gchar* song_pack=""; //This is additional information we store in song
 		if (i==0)
 			{
@@ -597,7 +597,8 @@ GList* song_init_songs_from_disk(){
 		//printf("base_path='%s'\n",base_path);
 		////////////////////
 
-
+		if (base_path==NULL)
+			continue;
 		GList* files = file_helper_get_all_files_without_path(base_path); //this is list of songs in this set
 		GList* l;
 		for (l = files; l; l = l->next)
@@ -613,8 +614,10 @@ GList* song_init_songs_from_disk(){
 			song->fullpath = g_strdup_printf("%s/%s",base_path,name_of_song);
 			song_prepare_icon(song);
 
+			g_free(l->data); //Free ghar* inside of this glist-entry
 			songs = g_list_append( songs,song);
 			}
+		g_free(base_path);
 		//Next folder
 		}
 	cem_add_to_log("song_init: loading from disk done",J_LOG_DEBUG);
