@@ -204,9 +204,10 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 		ClutterActor* icon_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename_for_icon_texture, NULL));
 		g_free(filename_for_icon_texture);
 
-		gchar* name_for_callback = g_strdup_printf("%s",full_image); //FIXME: this is not free'ed!
+		gchar* name_for_callback = g_strdup_printf("%s",full_image);
 		g_signal_connect (icon_button, "clicked", G_CALLBACK (save_image_pressed),theme);
 		clutter_actor_set_name(icon_button, name_for_callback);
+		g_free(name_for_callback);
 		clutter_actor_set_x(icon_button,x_place_for_icon);
 		clutter_actor_set_y(icon_button,200);
 		clutter_actor_set_width(icon_button,80); //This is the size/ratio when it is in cupboard
@@ -905,7 +906,7 @@ if (use_two_tracks) y_offset=80;
 	TangleVault* vault;
 
 	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
-	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
+	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault); //FIXME: this is not free'ed!
 
 	//Advanced-game: there are containers for samplebuttons, do not start hidden animations.
 	if (!chum_is_easy_game())
@@ -923,20 +924,16 @@ void delete_theme(jammo_theme* theme){
 
 	g_ptr_array_free(theme->sample_button_array,TRUE);
 
-	//TODO, free everything.
 	if (theme->save_menu_container != NULL){
-	clutter_actor_destroy(theme->save_menu_container);
+		clutter_actor_destroy(theme->save_menu_container);
 	}
 	//Free contents of tracks
 	//clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_hide), NULL);
 	//clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
 
-	//Hide this set of samplebuttons
-	clutter_actor_hide(theme->container);
-	//clutter_actor_destroy(theme->container); //TODO. use this
+	//Remove set of samplebuttons and all track_views and scrolling-actors etc.
+	clutter_actor_destroy(theme->container);
 
-	//g_free(theme->upper_track_view);
-	//g_free(theme->bottom_track_view);
-	//g_free(theme->sequencer);
+	g_object_unref(theme->sequencer);
 	g_free(theme);
 }
