@@ -51,25 +51,24 @@ void song_name_press_action(ClutterActor* loopName){
 				rename_loop(loopName, type);	
 		}else{
 			if(type == 0){ 
-				sequencer_start_with_file((char*)filename);
+				sequencer_start_with_file((gchar*)filename);
 			}else if(type == 1){ 
-				play_selected_loop((gchar*)filename);
+				play_selected_loop(loopName);
 			}
 		}
 	}	
 	
 }
 
-
 void rename_loop(ClutterActor *loopName, int type){
 
-	printf("Aloitetaan rename...\n");
-
 	static gboolean firstCall = TRUE;
 
-	ClutterActor *text = tangle_button_get_normal_background_actor(loopName);
+	ClutterActor *text = tangle_button_get_normal_background_actor(TANGLE_BUTTON(loopName));
+
 	const char* givenname = clutter_text_get_text(CLUTTER_TEXT(text));
 	const char* filename = clutter_actor_get_name(loopName);
+
 	printf("FILENAME:%s\n", filename);
 
 	if(firstCall == TRUE){
@@ -117,23 +116,23 @@ void rename_loop(ClutterActor *loopName, int type){
 			clutter_actor_set_name(loopName, newname);
 		}
 	}
-	printf("Poistutaan funktiosta rename...\n");
 }
 
-void play_selected_loop(gchar *loopName){
+void play_selected_loop(ClutterActor *actor){
 	
 	//TODO: add correct loop, this one is just to test the button
 	static JammoSample *sample = NULL;
-	
+	const char *filename = clutter_actor_get_name(actor);
+
 	if(sample == NULL){
 		//songName = "/home/teppo/jammo10-jammo-data/data/jammo7-12_all/backingtracks/Sa_LaBamba_110_A.ogg";
 		puts("Starting loop");
 
-		if(loopName == NULL){
+		if(actor == NULL){
 			sample = jammo_sample_new_from_file("/home/teppo/jammo10-jammo-data/data/jammo7-12_all/backingtracks/Sa_LaBamba_110_A.ogg");
 		}else{
-			printf("Now playing: %s\n",loopName);
-			sample = jammo_sample_new_from_file(loopName);
+			printf("Now playing: %s\n", filename);
+			sample = jammo_sample_new_from_file(filename);
 		}
 	
 		jammo_sample_play(sample);
@@ -149,22 +148,73 @@ void play_selected_loop(gchar *loopName){
 
 }
 
-void show_song_label(ClutterActor* songName){
+void show_song_label(show_label_params *params){
 
-	//TODO: show label
+	puts("Starting record label view.");
 
-	puts("Showing imaginary song label");
-}
-
-
-void show_music_video(ClutterActor* songName){
-
-	//TODO: play music video
+	FILE *file;
+	gchar data[200];	
+	gchar *recordName;
+	gchar *composer;
+	gchar *image;
+	if((file = fopen(params->path, "r")) != 0){
 	
-	puts("Showing imaginary music video");
-
+		if(fread(data, sizeof(gchar), 200, file) != 0){
+		
+			recordName = strtok(data, ",");
+			composer = strtok(NULL, ",");
+			image = strtok(NULL, ",");
+				
+			if(strcmp(recordName, "0") != 0 || strcmp(composer, "0") != 0 || strcmp(image, "0") != 0){
+				 
+				if(strcmp(params->parentview, "jammosongs") == 0) 				 
+					tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("jammosongs-view")));
+					
+				if(strcmp(params->parentview, "mysongs") == 0) 				 
+					tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("mysongs-view")));
+					
+				clutter_actor_show(jammo_get_actor_by_id("record-label-viewer"));
+				
+				g_signal_connect_swapped(jammo_get_actor_by_id("record-label-back-button"), "clicked", G_CALLBACK(hide_song_label), params->parentview);
+								
+				if(strcmp(recordName, "0") != 0)
+					clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("record-label-name")), recordName);
+				else clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("record-label-name")), "");
+					
+				if(strcmp(composer, "0") != 0)
+					clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("record-label-composer")), composer);
+				else clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("record-label-composer")), "");
+				
+				if(strcmp(image, "0") != 0){
+				
+					clutter_texture_set_from_file(CLUTTER_TEXTURE(jammo_get_actor_by_id("record-label-image")), image, NULL);
+					clutter_actor_show(jammo_get_actor_by_id("record-label-image"));
+					
+				}else clutter_actor_hide(jammo_get_actor_by_id("record-label-image"));
+				
+			
+			}
+			
+		}
+		
+		fclose(file);
+	}
+		
 }
 
+void hide_song_label(gchar* parentview){
+	
+	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("record-label-viewer")));
+	
+	if(strcmp(parentview, "jammosongs") == 0) 				 
+		clutter_actor_show(jammo_get_actor_by_id("jammosongs-view"));	
+		
+	if(strcmp(parentview, "mysongs") == 0) 				 
+		clutter_actor_show(jammo_get_actor_by_id("mysongs-view"));			
+		
+}
+
+
 time_type get_current_time(){
 
 	time_t now;
@@ -268,7 +318,7 @@ gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCa
 *
 */
 
-gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* path, int width, int height, GCallback function){
+gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* path, int width,int height, GCallback function){
 
 	button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(path, NULL));
 	clutter_actor_set_name(button, path);
@@ -289,12 +339,12 @@ gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* p
 */
 void limit_line_count(TextField *text){
 
-	gchar textField[500];
+	gchar *textField = malloc((text->max_characters+1) * sizeof(gchar));
 	PangoLayout *layout;
 	int index;
 	
-	strncpy(textField, clutter_text_get_text(CLUTTER_TEXT(text->text)), 499);
-	textField[499] = 0;
+	strncpy(textField, clutter_text_get_text(CLUTTER_TEXT(text->text)), text->max_characters);
+	textField[text->max_characters+1] = 0;
 
 	layout = clutter_text_get_layout(CLUTTER_TEXT(text->text));
 
@@ -318,6 +368,8 @@ void limit_line_count(TextField *text){
 		
 }
 
+
+
 /*
 * Frees dynamically allocated memory from GList that contains pointers to message structures.
 */
@@ -545,7 +597,7 @@ gboolean community_save_avatar(Avatar* avatar){
 * returns number of files found
 */
 
-int community_open_and_arrange_dir(char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
+int community_open_and_arrange_dir(const char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
 	
 	DIR *dir;
 	struct dirent *dir_ent;
@@ -579,7 +631,7 @@ int community_open_and_arrange_dir(char* path, char* suffix, char result[MAX_FIL
 			}
 		}
 	
-		qsort(result, numberOfFiles, MAX_FILE_NAME_LEN, strcoll);
+		qsort(result, numberOfFiles, MAX_FILE_NAME_LEN, (void*)strcoll);
 	
 		
 		closedir(dir);
@@ -689,6 +741,48 @@ void community_clear_paramslist(GList* paramsList){
 		
 		}   
 	}
+	
+	g_list_free(paramsList);
 
 }
 
+/*
+* Funtion frees GList that contains pointers to dynamically allocated show_label_params structures
+*/
+
+
+void community_clear_labelparamslist(GList* paramslist){
+
+	paramslist = g_list_first(paramslist);
+	
+	if(paramslist != NULL){
+	
+		g_free(((show_label_params*)paramslist->data)->path);
+		g_free(paramslist->data);   
+		   
+		while(paramslist->next != 0){
+			paramslist = paramslist->next;
+			g_free(((show_label_params*)paramslist->data)->path);
+			g_free(paramslist->data);
+		}   
+	}
+	
+	g_list_free(paramslist);
+
+}
+
+
+void community_autoscroll_to_correct_pos(list_type *list)
+{
+	gint slot;
+	gfloat not_used, offset;
+
+	ClutterAction *action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list->list), TANGLE_TYPE_SCROLL_ACTION);
+	
+	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(action), &not_used, &offset);
+
+	slot = (gint)offset % list->listItemHeight < list->listItemHeight / 2 ? (gint)(offset) / list->listItemHeight  
+							  		: (gint)(offset) / list->listItemHeight + 1;
+
+	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*list->listItemHeight), NULL);
+}
