@@ -12,6 +12,9 @@
 #define MAX_FILES_IN_DIR 50
 #define MAX_FILE_NAME_LEN 60
 
+#define TEXT_CAPTION "Comic Sans 24"
+#define TEXT_NORMAL "Comic Sans 14"
+
 typedef struct{
 	ClutterActor *body;
 	ClutterActor *hair;
@@ -36,12 +39,26 @@ typedef struct {
 	ClutterActor *text;
 	int lineCount;
 	gulong handler_id;
+	int max_characters;
 }TextField;
 
 typedef struct{
 	char time[19];
 }time_type;
 
+typedef struct{
+	ClutterContainer *list;
+	gint listItemHeight;
+}list_type;
+
+typedef struct{
+	
+	gchar* path;
+	gchar parentview[15];
+
+}show_label_params;
+	
+
 /*
 *Function computes the length of the click.
 *If the length of the click is more than 1 seconds, function to rename the item is called.
@@ -49,9 +66,10 @@ typedef struct{
 */
 void song_name_press_action(ClutterActor*);
 void rename_loop(ClutterActor *loopName, int type); 
-void play_selected_loop(gchar* loopName);
-void show_song_label(ClutterActor*);
-void show_music_video(ClutterActor*);
+void play_selected_loop(ClutterActor*);
+void show_song_label(show_label_params *params);
+void hide_song_label();
+
 
 /*
 * Function clears container that may contain other containers.
@@ -135,7 +153,7 @@ gboolean community_save_avatar(Avatar* avatar);
 *
 * returns number of files found
 */
-int community_open_and_arrange_dir(char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]);
+int community_open_and_arrange_dir(const char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]);
 
 /*
 * Transforms avatar into smaller scale, so it can be used in thread-views.
@@ -151,4 +169,12 @@ void community_shrink_and_set_avatar(Avatar* avatar, ClutterContainer *avatarBac
 */
 void community_clear_paramslist(GList* paramsList);
 
+/*
+* Funtion frees GList that contains pointers to dynamically allocated show_label_params structures
+*/
+
+void community_clear_labelparamslist(GList* paramslist);
+
+void community_autoscroll_to_correct_pos(list_type *list);
+
 #endif
