@@ -16,8 +16,8 @@ This file contains the functionality of help menu.
 #include <libintl.h>
 #include "../../cem/cem.h"
 
-static ClutterContainer *questionlist = 0;
-static gint listItemHeight = 0;
+static list_type questionslist = {0, 0};
+
 static int selectedQuestion = 0;
 static GList *helpdesk_messages = 0;
 static GList *paramsList = 0;
@@ -64,7 +64,7 @@ void end_helpdesk(void)
 	
 	paramsList = 0;
 
-	clear_container(questionlist);
+	clear_container(questionslist.list);
 	clear_messagelist(helpdesk_messages);
 	g_list_free(helpdesk_messages);
 }
@@ -120,11 +120,11 @@ void helpdesk_show_helpdesk_view(void)
 
 		if(number_of_questions > 4)
 		{
-			questionlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-scrollable"));	
-			ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(questionlist), TANGLE_TYPE_SCROLL_ACTION);
-			g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(helpdesk_autoscroll_to_correct_pos), questionlist);
+			questionslist.list = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-scrollable"));	
+			ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(questionslist.list), TANGLE_TYPE_SCROLL_ACTION);
+			g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), &questionslist);
 		}
-		else	questionlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-unscrollable"));
+		else	questionslist.list = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-unscrollable"));
 
 		if(number_of_questions != 0)
 		{	
@@ -150,7 +150,7 @@ void helpdesk_show_question_view(ClutterActor *actor)
 {
  	helpdesk_find_selected_actor(actor);
 
-	clear_container(questionlist);	
+	clear_container(questionslist.list);	
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -166,7 +166,7 @@ void helpdesk_show_addquestion_view(void)
 {
 	cem_add_to_log(_("Starting AddQuestion View"), J_LOG_DEBUG);
 
-	clear_container(questionlist);
+	clear_container(questionslist.list);
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -182,11 +182,13 @@ void helpdesk_show_addquestion_view(void)
 
 		addquestion_titleTextField.text = jammo_get_actor_by_id("helpdesk-addquestion-title");
 		addquestion_titleTextField.lineCount = 3;
+		addquestion_titleTextField.max_characters = 3;
 		addquestion_titleTextField.handler_id = g_signal_connect_swapped(addquestion_titleTextField.text,
 							"text-changed", (GCallback)limit_line_count, &addquestion_titleTextField);		
 
 		addquestion_questionTextField.text = jammo_get_actor_by_id("helpdesk-addquestion-description");
 		addquestion_questionTextField.lineCount = 9;
+		addquestion_questionTextField.lineCount = 3;
 		addquestion_questionTextField.handler_id = g_signal_connect_swapped(addquestion_questionTextField.text,
 							"text-changed", (GCallback)limit_line_count, &addquestion_questionTextField);		
 	}
@@ -240,21 +242,6 @@ void helpdesk_add_question(void)
 	helpdesk_show_helpdesk_view();
 }
 
-void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll)
-{
-	gint slot;
-	gfloat not_used, offset;
-
-	ClutterAction *action = tangle_actor_get_action_by_type(listToScroll, TANGLE_TYPE_SCROLL_ACTION);
-	
-	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(action), &not_used, &offset);
-
-	slot = (gint)offset % (gint)listItemHeight < listItemHeight / 2 ? (gint)(offset) / listItemHeight  
-							  		: (gint)(offset) / listItemHeight + 1;
-
-	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*listItemHeight), NULL);
-}
-
 gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 {	
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
@@ -281,7 +268,7 @@ gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 
 	paramsList = g_list_append(paramsList, params);
 
-	guint32 avatar_id = gems_profile_manager_get_avatar_id(NULL);
+	guint32 avatar_id = gems_profile_manager_get_avatar_id(gems_profile_manager_get_profile_of_user(user_id));
 
 	if (avatar_id == 0)
 		avatar_id = 260; //default avatar
@@ -299,9 +286,9 @@ gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 		return FALSE;	
 	}
 
-	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(composer) + 1;
+	if(questionslist.listItemHeight == 0) questionslist.listItemHeight = clutter_actor_get_height(composer) + 1;
 
-	clutter_actor_set_position(colorbar, 0, listItemHeight - 1);
+	clutter_actor_set_position(colorbar, 0, questionslist.listItemHeight - 1);
 	clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
 
 	clutter_actor_set_position(questionButton, 60, 23);			
@@ -317,19 +304,19 @@ gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 						clutter_actor_get_parent(commentButton));
 	g_signal_connect_swapped(CLUTTER_ACTOR(composer), "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
-	clutter_container_add_actor(questionlist, CLUTTER_ACTOR(listContainer));
+	clutter_container_add_actor(questionslist.list, CLUTTER_ACTOR(listContainer));
 
 	if(index <= 5)
-		clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * (index+1));	
+		clutter_actor_set_height(CLUTTER_ACTOR(questionslist.list), questionslist.listItemHeight * (index+1));	
 	else
-		clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * 5);		
+		clutter_actor_set_height(CLUTTER_ACTOR(questionslist.list), questionslist.listItemHeight * 5);		
 
 	return TRUE;
 }
 
 void helpdesk_find_selected_actor(ClutterActor *actor)
 {
-	GList *children = clutter_container_get_children(questionlist); //Get list of actors
+	GList *children = clutter_container_get_children(questionslist.list); //Get list of actors
 
 	int index = 0;
 	
