@@ -16,17 +16,17 @@ This file contains the functionality of JamMo Songs menu.
 #include "single_thread.h"
 #include "src/configure.h"
 #include "profile_viewer.h"
+#include "../../gems/gems_utils.h"
 
-
-static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
 static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data);
-static ClutterContainer *list = 0;
-static gint listItemHeight = 0;
+static list_type list = {0, 0};
 static gboolean isrecording_voice_comment = FALSE;
 static gboolean voice_comment_ready = FALSE;
 gchar* recording_filename;
 JammoSequencer* sequencer;
 GList *paramsList = 0;
+GList *labelParamsList = 0;
+
 
 void start_jammosongs(){
 
@@ -49,86 +49,79 @@ void start_jammosongs(){
 
 		
 		if(numberOfSongs > 5)
-			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosongs-songs-list-scrollable"));	
+			list.list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosongs-songs-list-scrollable"));	
 
 		else
-			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosongs-songs-list-unscrollable"));	
+			list.list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosongs-songs-list-unscrollable"));	
 
 
 		for(int i = 0; i < numberOfSongs; i++){
-			add_song_to_list(NULL, i, 0);	//TODO: third parameter must be user id of the composer
+			add_song_to_list(NULL, i, gems_profile_manager_get_userid(NULL));	
+			//TODO: third parameter must be user id of the composer, now we are using default
 		}
 
-	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list), TANGLE_TYPE_SCROLL_ACTION);
+	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list.list), TANGLE_TYPE_SCROLL_ACTION);
 
 	
-	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), list);
-
 	
+	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), &list);
+
+
 	}
 	else
 		puts("can't find 'jammosongs-view' ");
 }
 
 
-static void autoscroll_to_correct_pos(ClutterActor *listToScroll){
-
-	
-
-	gint slot;
-	gfloat not_used, offset;
-	ClutterAction *action = tangle_actor_get_action_by_type(listToScroll, TANGLE_TYPE_SCROLL_ACTION);
-	
-
-	
-	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(action), &not_used, &offset);
-	slot = (gint)offset % (gint)listItemHeight < listItemHeight/2  	? (gint)(offset) / listItemHeight  
-							  		: (gint)(offset) / listItemHeight + 1;
-
-	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", 
-				(gfloat)(slot*listItemHeight), NULL);
-}
-
 
 gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 
+	ClutterActor *listImage;
+	ClutterContainer *listContainer;
+	ClutterActor *reviewButton;
+	ClutterActor *avatarBackground;
+	ClutterActor *composer;
+	ClutterActor *songName;
+	ClutterActor *label = 0;
+	guint32 avatar_id = 0;
+	Avatar avatar = {0,0,0,0};
 	profile_view_params *params = malloc(sizeof(profile_view_params));
+	show_label_params *labelParams = malloc(sizeof(show_label_params));
+	gchar *command;
+
 	paramsList = g_list_append(paramsList, params);
 	strcpy(params->parent_view, "jammosongs");
 	params->user_id = user_id;
 
-	guint32 avatar_id = 0;
-	Avatar avatar = {0,0,0,0};
+	listImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar4.png", NULL); //TODO: image color depends on the song
 
-	ClutterActor *listImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar4.png", NULL); //TODO: image color depends on the song
+	listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
-	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
-
-	ClutterActor *reviewButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
+	reviewButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
 			"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
 	
-	ClutterActor *avatarBackground = clutter_group_new();	
+	avatarBackground = clutter_group_new();	
 	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
-	ClutterActor *composer = tangle_button_new_with_background_actor(avatarBackground);		
+	composer = tangle_button_new_with_background_actor(avatarBackground);		
 	
 			
 	//TODO: add correct font for the text		
 
-	ClutterActor *songName = tangle_button_new_with_background_actor(clutter_text_new_with_text("Times", "Name of the song"));
+	songName = tangle_button_new_with_background_actor(clutter_text_new_with_text("Times", "Name of the song"));
 
 	if(listImage == NULL)
 		return FALSE;	
 
-	if(listItemHeight == 0)
-		listItemHeight = clutter_actor_get_height(listImage);
+	if(list.listItemHeight == 0)
+		list.listItemHeight = clutter_actor_get_height(listImage);
 
 	clutter_container_add_actor(listContainer, listImage);
 	
-	clutter_actor_set_position(songName, 200, listItemHeight/5*2);
+	clutter_actor_set_position(songName, 200, list.listItemHeight/5*2);
 	
 	clutter_actor_set_position(composer, 20, 0);
 	
-	avatar_id = gems_profile_manager_get_avatar_id(NULL);
+	avatar_id = gems_profile_manager_get_avatar_id(gems_profile_manager_get_profile_of_user(user_id));
 	if (avatar_id == 0)
 		avatar_id = 260; //default avatar
 		
@@ -138,18 +131,21 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 	clutter_container_add_actor(listContainer, composer);
 	
 	clutter_container_add_actor(listContainer, songName);
-	
-	//TODO: add following images only if there is a music video or label for the song
-	
-	ClutterActor *video = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_videocamera_icon_small.png", NULL));
-	clutter_actor_set_position(video, 580, listItemHeight/3);
-	clutter_container_add_actor(listContainer, video);
 
-	ClutterActor *label = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
-
-	clutter_actor_set_position(label, 500, listItemHeight/3);
-	clutter_container_add_actor(listContainer, label);
+	labelParams->path = g_strdup_printf("%s/label_%d.csv", configure_get_jammo_directory(), user_id);
 	
+	command = g_strdup_printf("ls %s 1> /dev/null 2> /dev/null", labelParams->path);
+	
+	if(system(command) == 0){
+		label = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
+		clutter_actor_set_position(label, 500, list.listItemHeight/3);
+		clutter_container_add_actor(listContainer, label);
+	}
+
+
+	labelParamsList = g_list_append(labelParamsList, labelParams);
+
+	g_free(command);	
 
 	clutter_actor_set_position(CLUTTER_ACTOR(reviewButton), 700, 15);
 
@@ -159,20 +155,23 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 				clutter_actor_get_parent(reviewButton));
 
 	g_signal_connect_swapped(songName, "button-press-event", G_CALLBACK(song_name_press_action), songName);
-	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_press_action), songName);				
-	g_signal_connect_swapped(video, "clicked", G_CALLBACK(show_music_video), songName);
-	g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), songName);	
+	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_press_action), songName);		
+	
+	if(label != 0){	
+		strcpy(labelParams->parentview, "jammosongs");
+		g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), (gpointer)labelParams);
+		}	
 	
 	g_signal_connect_swapped(composer, "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
-	clutter_container_add_actor(list, CLUTTER_ACTOR(listContainer));
+	clutter_container_add_actor(list.list, CLUTTER_ACTOR(listContainer));
 	
 	
 	if(numberOfSongs <= 6)
-		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * numberOfSongs);	
+		clutter_actor_set_height(CLUTTER_ACTOR(list.list), list.listItemHeight * numberOfSongs);	
 
 	else
-		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * 6);		
+		clutter_actor_set_height(CLUTTER_ACTOR(list.list), list.listItemHeight * 6);		
 
 	return TRUE;
 
@@ -181,12 +180,12 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 
 void review_selected_song(ClutterActor *song){
 
-	GList *children = clutter_container_get_children(list);
+	GList *children = clutter_container_get_children(list.list);
 	GList* messages = NULL;
 	//TODO: get messages to list
 	message *msg;
 	int i;
-	time_t now;
+	//time_t now; //this might be needed later...
 
 	if(isrecording_voice_comment)
 		stop_recording();
@@ -210,7 +209,14 @@ void review_selected_song(ClutterActor *song){
 		strcpy(msg->time, "21.1.2011 10:09");
 		msg->type = TEXT_COMMENT;
 
+		/*if(voice_comment_ready == TRUE){
+			strcpy(msg->filepath, g_strdup_printf("%s/last_recorded.ogg",configure_get_jammo_directory()) );
+			msg->type = VOICE_COMMENT;
+			voice_comment_ready == FALSE;
+		}*/
 		messages = g_list_append(messages, (gpointer)msg);
+
+		//TO-DO: Delete last_recorded after sending it to server
 	}
 
 	int first = 0;
@@ -226,7 +232,7 @@ void review_selected_song(ClutterActor *song){
 		
 			if(song == children->data){
 				puts("found it");
-				clear_container(list);
+				clear_container(list.list);
 				ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 				clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 				start_thread_view(messages, "jammosongs", NULL, 0);
@@ -245,14 +251,23 @@ void review_selected_song(ClutterActor *song){
 
 void end_jammosongs(TangleButton *tanglebutton, gpointer none){
 
+	community_clear_labelparamslist(labelParamsList);
+
+	labelParamsList = 0;
+
 	community_clear_paramslist(paramsList);
 
 	paramsList = 0;
 
-	clear_container(list);
+	clear_container(list.list);
 
 	if(isrecording_voice_comment)
 		stop_recording();
+
+	if(voice_comment_ready){
+		voice_comment_ready = FALSE;
+		remove(recording_filename);
+	}
    
 	if(strcmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)), "gotocommunity") == 0)
 		startmenu_goto_communitymenu(tanglebutton, none);
@@ -296,8 +311,6 @@ void record_voice_comment(){
 	
 }
 
-
-
 void stop_recording()
 {
 	isrecording_voice_comment = FALSE;
@@ -315,23 +328,23 @@ static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data)
 void rec_press_action(ClutterActor *song){
 
 	
-	GList *children = clutter_container_get_children(list);
+	GList *children = clutter_container_get_children(list.list);
 	GList* messages = NULL;
 	//TODO: get messages to list
-	message *msg;
-	int i;
-	time_t now;
+	//message *msg;//this might be needed later...
+	//int i;//this might be needed later...
+	//time_t now;//this might be needed later...
 
 
 //NOTE: when creting messages, message structure and variables msg and avatar inside structure
 //	must be dynamically allocated
-puts("1");
+
 	
 	
 	int first = 0;
 	
 	if(children != NULL){
-puts("2");		
+		
 		do{
 			if(first == 0)
 				first++;
@@ -341,7 +354,7 @@ puts("2");
 		
 			if(song == children->data){puts("3");
 				puts("found it");
-				clear_container(list);
+				clear_container(list.list);
 				ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 				clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);//TODO: get voice comments of the song
 				start_thread_view(messages, "jammosongs-voice", NULL, 0);
