@@ -66,15 +66,14 @@ void start_jammosounds(){
 gboolean add_loop_to_list(char* name, int numberOfLoops){
 
 	ClutterActor* listImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_jammosounds_bar.png", NULL);
-
-
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
-
 	ClutterActor *importButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-			"/opt/jammo/communitymenu/community_icon_toloopgame.png", NULL));
-			
+			"/opt/jammo/communitymenu/community_icon_toloopgame.png", NULL));			
 	ClutterActor *arrowImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_rightarrow.png", NULL);
-
+	ClutterActor *instrument;
+	ClutterActor *text;
+	ClutterActor *loopName;
+	
 	if(listImage == NULL || arrowImage == NULL)
 		return FALSE;	
 
@@ -87,7 +86,7 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	
 	//TODO: add instrument icon depending on the instrument
 
-	ClutterActor *instrument = clutter_texture_new_from_file("/opt/jammo/wheel_game/piano.png", NULL);  
+	instrument = clutter_texture_new_from_file("/opt/jammo/wheel_game/piano.png", NULL);  
 	clutter_actor_set_position(instrument, 130, 0);
 	clutter_actor_set_height(instrument, listItemHeight);
 	clutter_container_add_actor(listContainer, instrument);
@@ -95,8 +94,8 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	
 	//TODO: add correct font	
 	
-	ClutterActor *text = clutter_text_new_with_text("Comic Sans MS", "Loop name here");	
-	ClutterActor *loopName = tangle_button_new_with_background_actor(text);
+	text = clutter_text_new_with_text("Comic Sans MS", "Loop name here");	
+	loopName = tangle_button_new_with_background_actor(text);
 	clutter_actor_set_position(loopName, 230, listItemHeight/5*2);
 	clutter_container_add_actor(listContainer, loopName);	
 
