@@ -17,7 +17,11 @@ void mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 //Functions for creating and moving loops
 gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops);
 void mysongs_autoscroll_to_correct_pos(ClutterActor *listToScroll);
-
+void mysongs_delete_song(ClutterActor *actor);
+void mysongs_remove_song_view(ClutterActor *actor);
+void mysongs_cancel_song_delete(ClutterActor *actor);
+void mysongs_get_comments(ClutterActor* song);
 void mysongs_comment(ClutterActor *actor);
+void mysongs_refresh_list();
 
 #endif 
