@@ -51,23 +51,29 @@ TangleButton* last_pressed_volume_button = NULL;
 
 
 
-/*
- * Event for pressing label of track.
- * data is track_view when saved game is loaded (and actors are created from c)
- * else name of buttons parent (=control-panel-widget) is used for jammo_get_actor_by_id (actors created from json)
- */
+
+
+
+
 gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data) {
 	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
-	TangleWidget* track_view;
+	TangleWidget* track_view=NULL;
 
-	if (data) //Check if data contains track-view (when loading game from file)
-		track_view = TANGLE_WIDGET(data);
-	else //Check if name contains id of track-view (when starting from level.json)
-		track_view = TANGLE_WIDGET(jammo_get_actor_by_id(name));
+
+	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	GList* children;
+	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(container)); children; children = children->next) {
+		const gchar* name2 = clutter_actor_get_name(CLUTTER_ACTOR(children->data));
+		if (strcmp(name,name2)==0){
+			track_view=TANGLE_WIDGET(children->data);
+		}
+	}
 
 	if (track_view==NULL) {
-		cem_add_to_log("Can't find what track is asked",J_LOG_USER_ACTION);
+		gchar* message = g_strdup_printf(" Not found track named '%s' for label-pressed",name);
+		cem_add_to_log(message,J_LOG_FATAL);
+		g_free(message);
 		return FALSE;
 	}
 
@@ -142,10 +148,7 @@ gboolean fullsequencer_mentor_clicked (TangleButton *tanglebutton, gpointer data
 	return TRUE;
 }
 
-/*
- * data is track_view when saved game is loaded (and actors are created from c)
- * else name of buttons parent (=control-panel-widget) is used for jammo_get_actor_by_id (actors created from json)
- */
+
 gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer data)   {
 	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
@@ -153,21 +156,28 @@ gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer dat
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 
-	TangleWidget* track_view;
+	TangleWidget* track_view=NULL;
 
 	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	if (data)
-		track_view=TANGLE_WIDGET(data);
-	else
-		track_view = TANGLE_WIDGET(tangle_widget_get_nth_child(TANGLE_WIDGET(container),atoi(name)));
+	GList* children;
+	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(container)); children; children = children->next) {
+		const gchar* name2 = clutter_actor_get_name(CLUTTER_ACTOR(children->data));
+		if (strcmp(name,name2)==0){
+			track_view=TANGLE_WIDGET(children->data);
+		}
+	}
 
-	JammoPlayingTrack* jammotrack;
+	if (track_view==NULL) {
+		gchar* message = g_strdup_printf(" Not found track named '%s' for muting",name);
+		cem_add_to_log(message,J_LOG_FATAL);
+		g_free(message);
+		return FALSE;
+	}
 
-	//slider is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	JammoPlayingTrack* jammotrack=NULL;
+	//slider/backingtrack is inside of generic jammo_track_view, miditrack is inside of miditrack-view  and loop-track inside editing-track-view
 	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view)  || JAMMO_IS_TRACK_VIEW(track_view) ) {
 		g_object_get(track_view, "track", &jammotrack, NULL);
-	} else if (TANGLE_IS_WIDGET(track_view)) {
-		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view),"track"));
 	} else  {
 		return FALSE;
 	}
@@ -178,27 +188,12 @@ gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer dat
 	return TRUE;
 }
 
-
-
-/**
-This syncs scrollers offset to tracks volume.
+/*
+When track is created from saved projects and it has starting volume, this function is called.
+Also when user moves volume-slider, this is called.
 */
-gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
-	//printf("sequencer_volumebar_used\n");
-	if (!last_pressed_volume_button)
-		return FALSE;
-
-	ClutterActor* volume_scroller = clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(scroll_action));
-	//-50 is height of the visible marker.
-	gfloat height = clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50;
-	gfloat offset,not_used;
-	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), &not_used,&offset);
-
-	JammoPlayingTrack* jammotrack = g_object_get_data(G_OBJECT(volume_scroller),"track");
-
-	gfloat new_volume = offset/height; //This is between [0...1]
-	if (jammo_playing_track_get_volume(jammotrack) == new_volume)
-		return FALSE;
+static void set_track_volume_and_button_texture(JammoPlayingTrack* jammotrack, TangleButton* volume_button, gfloat new_volume) {
+	//printf("changing volume to %f\n",new_volume);
 
 	jammo_playing_track_set_volume(jammotrack,new_volume);
 
@@ -206,11 +201,11 @@ gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 
-	//These are for changing texture of volume-button
-	ClutterActor* container = tangle_button_get_normal_background_actor(last_pressed_volume_button);
+	//Change texture of volume-button
+	ClutterActor* container = tangle_button_get_normal_background_actor(volume_button);
 	ClutterActor* nub = tangle_widget_get_nth_child(TANGLE_WIDGET(container),0);
 
-	ClutterActor* container2 = tangle_button_get_selected_background_actor(last_pressed_volume_button);
+	ClutterActor* container2 = tangle_button_get_selected_background_actor(volume_button);
 	ClutterActor* nub2 = tangle_widget_get_nth_child(TANGLE_WIDGET(container2),0);
 
 	gfloat height_ = 36; //clutter_actor_get_height(container) - clutter_actor_get_height(nub); //If hided. container reports it's height wrongly
@@ -218,6 +213,34 @@ gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
 
 	clutter_actor_set_y(nub,height_-new_volume*height_);
 	clutter_actor_set_y(nub2,height_-new_volume*height_);
+}
+
+
+/**
+This syncs scrollers offset to tracks volume.
+*/
+gboolean sequencer_volumebar_used (ClutterAction* scroll_action, gpointer none){
+	//printf("sequencer_volumebar_used\n");
+	if (!last_pressed_volume_button)
+		return FALSE;
+
+
+	ClutterActor* volume_scroller = clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(scroll_action));
+	JammoPlayingTrack* jammotrack = g_object_get_data(G_OBJECT(volume_scroller),"track");
+
+	gfloat height = clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50;
+
+	gfloat offset;
+	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), NULL,&offset);
+
+
+
+	gfloat new_volume = offset/height; //This is between [0...1]
+	//If volume is changed
+		if (jammo_playing_track_get_volume(jammotrack) != new_volume)
+			set_track_volume_and_button_texture(jammotrack,last_pressed_volume_button,new_volume);
+
+
 	return FALSE;
 }
 
@@ -236,26 +259,32 @@ gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer d
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 
-	TangleWidget* track_view;
+	TangleWidget* track_view=NULL;
 
 	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	if (data)
-		track_view=TANGLE_WIDGET(data);
-	else
-		track_view = TANGLE_WIDGET(tangle_widget_get_nth_child(TANGLE_WIDGET(container),atoi(name)));
+	GList* children;
+	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(container)); children; children = children->next) {
+		const gchar* name2 = clutter_actor_get_name(CLUTTER_ACTOR(children->data));
+		if (strcmp(name,name2)==0){
+			track_view=TANGLE_WIDGET(children->data);
+		}
+	}
 
-	JammoPlayingTrack* jammotrack;
+	if (track_view==NULL) {
+		gchar* message = g_strdup_printf(" Not found track named '%s'",name);
+		cem_add_to_log(message,J_LOG_FATAL);
+		g_free(message);
+		return FALSE;
+	}
 
 	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
 	ClutterActor* volume_scroller = jammo_get_actor_by_id("fullsequencer-volumebar-scroller");
 	ClutterAction* scroll_action = tangle_actor_get_action_by_type(volume_scroller,TANGLE_TYPE_SCROLL_ACTION);
 
-
-	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	JammoPlayingTrack* jammotrack=NULL;
+	//slider/backingtrack is inside of generic jammo_track_view, miditrack is inside of miditrack-view  and loop-track inside editing-track-view
 	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view)  || JAMMO_IS_TRACK_VIEW(track_view) ) {
 		g_object_get(track_view, "track", &jammotrack, NULL);
-	} else if (TANGLE_IS_WIDGET(track_view)) {
-		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view),"track"));
 	} else  {
 		return FALSE;
 	}
@@ -342,7 +371,7 @@ void fullsequencer_play_loaded (TangleButton* tanglebutton, gpointer none){
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
  TangleBinding* binding;
- binding = tangle_binding_new(G_OBJECT(tanglebutton), "selected", G_OBJECT(sequencer), "play");
+ binding = tangle_binding_new(G_OBJECT(tanglebutton), "selected", G_OBJECT(sequencer), "play"); //this is never free'ed!
 }
 
 
@@ -363,7 +392,7 @@ void sequencer_track_view_tune_width() {
 	guint64 duration;
 	duration = jammo_sequencer_get_duration(sequencer);
 
-	g_print("Duration: %" G_GUINT64_FORMAT "\n", duration);
+	//g_print("Duration: %" G_GUINT64_FORMAT "\n", duration);
 
 	gint tempo_factory = 4;
 	//We want operate whole time with guint64.
@@ -373,7 +402,7 @@ void sequencer_track_view_tune_width() {
 	guint64 duration_of_one_slot = big / jammo_sequencer_get_tempo(sequencer);
 
 	gint n_slots = duration/duration_of_one_slot;
-	printf("*number_of_slots (in backing-track / for editing-track): %d\n",n_slots);
+	//printf("*number_of_slots (in backing-track / for editing-track): %d\n",n_slots);
 
 
 	//Set static
@@ -423,25 +452,27 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 	// It is toggle-button. Both states are tangle_widgets with background+nub
 	ClutterActor* volume_background = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png", NULL);
 	ClutterActor* volume_background2 = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png", NULL);
+	ClutterActor* volume_background3 = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png", NULL);
 	ClutterActor* volume_nub = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_button.png", NULL);
 	ClutterActor* volume_nub_selected = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_button_selected.png", NULL);
 
 	ClutterActor* volume_button_idle = tangle_widget_new();
 	ClutterActor* volume_button_selected = tangle_widget_new();
+	ClutterActor* volume_button_interactive = tangle_widget_new();
 
 	g_object_set(volume_button_idle, "background-actor", volume_background, NULL);
 	g_object_set(volume_button_selected, "background-actor", volume_background2,NULL);
+	g_object_set(volume_button_interactive, "background-actor", volume_background3,NULL);
 
 	tangle_widget_add(TANGLE_WIDGET(volume_button_idle),volume_nub,NULL);
 	tangle_widget_add(TANGLE_WIDGET(volume_button_selected),volume_nub_selected,NULL);
 
 	ClutterActor* volume_button = tangle_button_new_selectable_with_background_actors (
        volume_button_idle,/* normal */
-       volume_button_selected,  /* interactive */
+       volume_button_interactive,  /* interactive */
        volume_button_selected); /* selected */
 
 	clutter_actor_set_size(volume_button, track_height-4,track_height-4); //it is square. Four pixels marginal
-	tangle_button_set_selected(TANGLE_BUTTON(volume_button),muted);
 
 	g_signal_connect(volume_button, "clicked", G_CALLBACK(pressed_sequencer_button_volume), track_view_actor);
 	tangle_widget_add(TANGLE_WIDGET(panel_widget),volume_button,NULL);
@@ -451,6 +482,19 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 	container = jammo_get_actor_by_id("fullsequencer-track-control-panel");
 	clutter_container_add_actor(CLUTTER_CONTAINER(container),panel_widget);
 	clutter_actor_set_height(container,clutter_actor_get_height(container)+track_height);
+
+	//Set saved volume
+	ClutterActor* volume_scroller = jammo_get_actor_by_id("fullsequencer-volumebar-scroller");
+	ClutterAction* scroll_action;
+	scroll_action = tangle_actor_get_action_by_type(volume_scroller, TANGLE_TYPE_SCROLL_ACTION);
+
+	JammoPlayingTrack* jammotrack;
+	g_object_get(track_view_actor,"track",&jammotrack,NULL);
+
+	set_track_volume_and_button_texture(jammotrack, TANGLE_BUTTON(volume_button),volume);
+
+	//Set saved mute-state
+	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), muted);
 }
 
 
