@@ -59,12 +59,14 @@ void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int ind
 		}else if(strcmp(id, "discuss") == 0){
 			text.text = jammo_get_actor_by_id("answer-field");
 			text.lineCount = 8;
+			text.max_characters = 500;
 			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
 			clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 
 		}else if(strcmp(id, "helpdesk") == 0){
 			text.text = jammo_get_actor_by_id("answer-field");
 			text.lineCount = 6;
+			text.max_characters = 500;
 			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
 			clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 		}	
@@ -101,6 +103,7 @@ void text_comment_view(){
 	clutter_actor_show(jammo_get_actor_by_id("text-answer-widgets"));
 	text.text = jammo_get_actor_by_id("answer-field");
 	text.lineCount = 6;
+	text.max_characters = 500;
 	text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
 	clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 
@@ -116,17 +119,17 @@ printf("%d   %d \n", i, msg->index);
 		int index = 0;
 		int MAX = 500;
 		int h = 80;
-puts("1");		
+		
 		profile_view_params *params = malloc(sizeof(profile_view_params));
 		
 		paramsList = g_list_append(paramsList, params);
 		
 		params->user_id = msg->user_id;
 		strcpy(params->parent_view, "single-thread");
-puts("2");		
+		
 		Avatar avatar = {0,0,0,0};
 		guint32 avatar_id;
-		avatar_id = gems_profile_manager_get_avatar_id(gems_profile_get_profile_of_user(msg->user_id));
+		avatar_id = gems_profile_manager_get_avatar_id(gems_profile_manager_get_profile_of_user(msg->user_id));
 		
 		if(avatar_id == 0)
 			avatar_id = 260; //default avatar
@@ -138,7 +141,7 @@ puts("2");
 	
 		ClutterColor text_color = { 0, 0, 0, 255 };
 		ClutterColor line_color = { 144, 148, 140, 255 };
-puts("3");
+
 
 		ClutterActor* avatarBackground = clutter_group_new();
 		
@@ -151,7 +154,7 @@ puts("3");
 		community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));
 		clutter_container_add_actor(CLUTTER_CONTAINER(listContainer), writer);
 		
-puts("4");
+
 	
 		index = (index+1) % 3;
 
@@ -175,7 +178,7 @@ puts("4");
 		clutter_container_add_actor(listContainer, date);
 		
 		g_signal_connect_swapped(writer, "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
-puts("5");		
+		
 
 		if(msg->type == TEXT_COMMENT){
 			ClutterActor* message = clutter_text_new_full("Comic Sans MS 12", msg->msg, &text_color);
@@ -193,6 +196,8 @@ puts("5");
 			
 			strcpy(filepath, msg->filepath);
 
+			printf("Filepath on:%s\n", filepath);
+
 			ClutterActor* play_button = 0;
 			play_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL)); 
 			clutter_actor_set_position(play_button, 400, 1);
@@ -258,10 +263,14 @@ void add_voice_comment(){
 	}else{
 		stop_recording();
 		isrecording = FALSE;
+
 		clear_container(messageList);
+
 		msg = malloc(sizeof(message));
+
 		now = get_current_time();
 		msg->type = VOICE_COMMENT;
+
 		strcpy(msg->sender, "Sender");
 		strcpy(msg->title, "");
 		msg->user_id = 0;
@@ -270,6 +279,7 @@ void add_voice_comment(){
 		msg->filepath = g_strdup_printf("%s/last_recorded.ogg",configure_get_jammo_directory());
 		msg->msg = 0;
 		msg->index = 0;
+
 		messages = g_list_append(messages, (gpointer)msg);
 
 		start_thread_view(messages, id, NULL, selected_index);		
@@ -294,7 +304,7 @@ void end_single_thread(){
 	if(strcmp(id, "helpdesk") == 0 )
 	start_helpdesk();
 
-	else if (strcmp(id, "jammosongs") == 0 )
+	else if (strcmp(id, "jammosongs") == 0)
 	start_jammosongs();
 
 	else if (strcmp(id, "jammosounds") == 0)
