@@ -6,6 +6,8 @@
 void start_thread_view(GList*, gchar *id_, gchar *params, int index);
 void add_message_to_list(gpointer data, int i);
 void add_comment();
+void text_comment_view();
+void add_voice_comment();
 void end_single_thread();
 
 #endif
