@@ -38,24 +38,14 @@ void startmenu_mentor_clicked(TangleButton* tanglebutton, gpointer none){
 }
 
 void startmenu_draw_version_information(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-
 	//Show version number: defined in configure.ac
-	/* TRANSLATORS: This is used on startmenu to concatenate Version-0.7.7 */
-	gchar* version = g_strdup_printf("%s-%s",gettext("Version"),VERSION);
-	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 36",version);
-	ClutterColor text_color = { 255, 255, 0, 255 };
-	clutter_actor_set_x(version_label,10.0);
-	clutter_text_set_color(CLUTTER_TEXT(version_label), &text_color);
-	g_free(version);
-	ClutterActor* actor = jammo_get_actor_by_id("startmenu-view");
-	clutter_container_add_actor (CLUTTER_CONTAINER (actor), version_label);
+	ClutterActor* version_label =  jammo_get_actor_by_id( "startmenu-version-info");
+	clutter_text_set_font_name (CLUTTER_TEXT(version_label),"Luxi Mono 36");
 
-	/* //Doesn't work. startmenu-version-info is not loaded when this funtion is called
-	ClutterActor* text_actor = jammo_get_actor_by_id( "startmenu-version-info");
-	gchar* version = g_strdup_printf("Version-%s",VERSION);
-	clutter_text_set_text(CLUTTER_TEXT(text_actor), version);
+	/* TRANSLATORS: This is used on startmenu to concatenate Version information e.g. Version-0.7.13 */
+	gchar* version = g_strdup_printf("%s-%s",gettext("Version"),VERSION);
+	clutter_text_set_text(CLUTTER_TEXT(version_label), version);
 	g_free(version);
-	*/
 }
 
 void startmenu_quit (TangleButton* tanglebutton, gpointer none){
