@@ -12,6 +12,7 @@ This file contain helper functions, which are meant to be used via chum.
 #include <tangle.h>
 
 #include "../configure.h" //e.g. DATA_DIR
+#include "jammo-track-view.h"
 #include "jammo-editing-track-view.h"
 #include "jammo-miditrack-view.h"
 #include "../meam/jammo-slider-track.h"
@@ -37,7 +38,7 @@ This file contain helper functions, which are meant to be used via chum.
 		something_writted=TRUE; \
 		}\
 	if (jammo_playing_track_get_muted(JAMMO_PLAYING_TRACK(track))) {\
-			fprintf(ofp,",\n\t\"muted\" : \"true\"\n"); \
+			fprintf(ofp,",\n\t\"muted\" : true\n"); \
 			something_writted=TRUE; \
 			} \
 	if (!something_writted) {\
@@ -102,6 +103,7 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 
 
 		if (JAMMO_IS_EDITING_TRACK_VIEW(track_view)){
+			cem_add_to_log(" Saving EditingTrack",J_LOG_DEBUG);
 			FIRST_TRACK_STARTS_WITHOUT_COMMA
 
 			fprintf(ofp,"\n\t{\n");
@@ -109,6 +111,9 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 
 			g_object_get(track_view,"track",&track,NULL);
 
+			const gchar* name_of_track = clutter_actor_get_name(track_view);
+			fprintf(ofp,"\t\"name\" : \"%s\",\n",name_of_track);
+
 			JammoSampleType type;
 			g_object_get(track_view,"sample-type", &type,NULL);
 
@@ -166,6 +171,7 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 
 
 		else if (JAMMO_IS_MIDITRACK_VIEW(track_view)){
+			 cem_add_to_log(" Saving MidiTrack",J_LOG_DEBUG);
 			 FIRST_TRACK_STARTS_WITHOUT_COMMA
 
 			g_object_get(track_view,"track",&track,NULL);
@@ -190,11 +196,12 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 			fprintf(ofp,"\t}");
 		}//Jammo-Midtrack-View ends
 
-		else if (TANGLE_IS_WIDGET(track_view)){
-
-			track = g_object_get_data(G_OBJECT(track_view), "track");
+		else if (JAMMO_IS_TRACK_VIEW(track_view)){
+			cem_add_to_log(" Saving common TRACK_VIEW...",J_LOG_DEBUG);
+			g_object_get(track_view,"track",&track,NULL);
 
 			if (JAMMO_IS_SLIDER_TRACK(track)) {
+			cem_add_to_log("  Saving SliderTrack",J_LOG_DEBUG);
 			FIRST_TRACK_STARTS_WITHOUT_COMMA
 			int type;
 			g_object_get(track,"slider-type",&type,NULL);
@@ -219,6 +226,7 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 			}//Jammo-Slider-Track ends
 
 			else if (JAMMO_IS_BACKING_TRACK(track)) {
+			cem_add_to_log("  Saving BackingTrack",J_LOG_DEBUG);
 			FIRST_TRACK_STARTS_WITHOUT_COMMA
 			gchar *filename;
 			g_object_get(track,"filename",&filename,NULL);
@@ -436,6 +444,7 @@ GList *file_helper_get_all_files(char* directory) {
       song_list = g_list_append( song_list,song_name);
       //printf("added to list: '%s'\n",song_name);
       }
+  g_list_foreach(song_folders,(GFunc)g_free,NULL);
   return song_list;
 }
 
@@ -460,5 +469,6 @@ GList *file_helper_get_all_files_without_path(char* directory) {
       song_list = g_list_append( song_list,song_name);
       //printf("added to list: '%s'\n",song_name);
       }
+  g_list_foreach(song_folders,(GFunc)g_free,NULL);
   return song_list;
 }
