@@ -66,7 +66,9 @@ ClutterActor* jammo_get_actor_by_id(const char* id) {
 	ClutterActor* actor = NULL;
 
 	if (!(actor = CLUTTER_ACTOR(clutter_script_get_object(script, id)))) {
-		g_warning("Actor '%s' not found.", id);
+		gchar* message = g_strdup_printf("Actor '%s' not found.", id);
+		cem_add_to_log(message, J_LOG_WARN);
+		g_free(message);
 	}
 	
 	return actor;
@@ -76,7 +78,9 @@ GObject* jammo_get_object_by_id(const char* id) {
 	GObject* object = NULL;
 
 	if (!(object = clutter_script_get_object(script, id))) {
-		g_warning("Object '%s' not found.", id);
+		gchar* message = g_strdup_printf("Object '%s' not found.", id);
+		cem_add_to_log(message, J_LOG_WARN);
+		g_free(message);
 	}
 	
 	return object;
@@ -187,12 +191,109 @@ static gint rpc_callback(const gchar* interface, const gchar* method, GArray* ar
 }
 #endif
 
+/*
+Parse settings file
+If file is not found (or some other error case) values are not modifed.
+ -> Caller should set own defaults before calling,
+ (or check against NULL)
+*/
+static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang) {
+	JsonParser *parser;
+	parser = json_parser_new ();
+	g_assert (JSON_IS_PARSER (parser));
+
+	if (!json_parser_load_from_file (parser, filename, NULL))
+		{
+		printf("jammo-main: read_config_file: Can't load settings file '%s'.\n", filename);
+		g_object_unref (parser);
+		return;
+		}
+
+	JsonNode *root;
+	JsonObject *object;
+	JsonNode *node;
+
+	g_assert (NULL != json_parser_get_root (parser));
+
+	//g_print ("checking root node is an object...\n");
+	root = json_parser_get_root (parser);
+	g_assert_cmpint (JSON_NODE_TYPE (root), ==, JSON_NODE_OBJECT);
+
+	object = json_node_get_object (root);
+	g_assert (object != NULL);
+
+
+	//Settings for logging
+	node = json_object_get_member (object, "WRITE_LOG_ALSO_STDOUT");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		*log_stdout = json_node_get_boolean (node);
+
+	node = json_object_get_member (object, "LOG_DEBUG");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_DEBUG;
+
+	node = json_object_get_member (object, "LOG_INFO");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_INFO;
+
+	node = json_object_get_member (object, "LOG_FATAL");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_FATAL;
+
+	node = json_object_get_member (object, "LOG_ERROR");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_ERROR;
+
+	node = json_object_get_member (object, "LOG_WARN");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_WARN;
+
+	node = json_object_get_member (object, "LOG_USER_ACTION");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_USER_ACTION;
+
+	node = json_object_get_member (object, "LOG_NETWORK");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_NETWORK;
+
+	node = json_object_get_member (object, "LOG_NETWORK_DEBUG");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_NETWORK_DEBUG;
+
+	node = json_object_get_member (object, "LOG_MENTOR_SPEECH");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		if( json_node_get_boolean (node))
+			*log_level+=J_LOG_MENTOR_SPEECH;
+
+	//LANGUAGE of Mentor
+	const gchar* mlang=NULL;
+	node = json_object_get_member (object, "MENTOR_LANGUAGE");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		mlang = json_node_get_string (node);
+		if (mlang) {
+			g_free(*mentor_lang); //Free default value.
+			*mentor_lang = g_strdup_printf("%s",mlang);
+		}
+
+	g_object_unref (parser);
+}
+
+
 /*
  Order of initialization:
  * Configure (define directories and creates them if needed)
+ * CHUM (graphical)
+ * Read settings-files
  * CEM  (Logging)
  * MEAN (audio)
- * CHUM (graphical)
  * GEMS (network)
  * [N900: osso-context (+keep-a-live for display) ]
  * gettext (locales)
@@ -213,15 +314,20 @@ int main(int argc, char** argv) {
 	osso_context_t* osso_context;
 #endif
 
-	cem_set_log_level(J_LOG_DEBUG
-		+J_LOG_INFO
-		+J_LOG_FATAL
-		+J_LOG_ERROR
-		+J_LOG_WARN
-		+J_LOG_USER_ACTION
-		+J_LOG_NETWORK
-		+J_LOG_NETWORK_DEBUG
-		+J_LOG_MENTOR_SPEECH);
+	jammo_chum_init(&argc, &argv);
+
+	//these can be changed via SETTINGS-file
+	gboolean log_to_stdout = FALSE;
+	int log_level=J_LOG_NONE;
+	gchar* lang_of_mentor = g_strdup_printf("system");
+
+	gchar* setting_file = g_strdup_printf("%s/jammo.config",configure_get_jammo_directory());
+	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor);
+	g_free(setting_file);
+
+	//LOGGING
+	cem_print_also_to_stdout(log_to_stdout);
+	cem_set_log_level(log_level);
 
 	gchar* message = g_strdup_printf("JamMo-%s started",VERSION);
 	cem_add_to_log(message, J_LOG_INFO);
@@ -247,7 +353,7 @@ int main(int argc, char** argv) {
 	}
 
 	jammo_meam_init(&argc, &argv, duration_cache_filename);
-	jammo_chum_init(&argc, &argv);
+
 	
 	/* GEMS initialization and profile manager test */
 #ifdef NETWORKING_ENABLED
@@ -294,7 +400,8 @@ int main(int argc, char** argv) {
 	/* TRANSLATORS: This is used on main, when gettext is first time used */
 	gchar* localized = g_strdup_printf("main: %s",_("gettext initialized"));
 	message = g_strdup_printf("%s",localized);
-	cem_add_to_log(message, J_LOG_DEBUG);
+	g_free(localized);
+	cem_add_to_log(message, J_LOG_INFO);
 	g_free(message);
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
@@ -361,22 +468,24 @@ int main(int argc, char** argv) {
 	//do not show mentor on startup
 	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
 
-	gchar* lang = getenv ("LANG");
-	message = g_strdup_printf("getenv(LANG)='%s'",lang);
-	cem_add_to_log(message, J_LOG_DEBUG);
-	g_free(message);
+	if (strncmp(lang_of_mentor,"system",6)==0) {
+		gchar* lang = getenv ("LANG");
+		message = g_strdup_printf("getenv(LANG)='%s'",lang);
+		cem_add_to_log(message, J_LOG_DEBUG);
+		g_free(message);
 
-
-
-	gchar* lang2=g_strndup (lang,5); //omit charset.
+		g_free(lang_of_mentor); //we overwrite text 'system'
+		lang_of_mentor=g_strndup (lang,5); //omit charset.
+	}
 	gchar* path;
 	if (!strcmp(application_name,"jammo7_12"))
-		path = g_strdup_printf("mentor_speech7_12/%s/mentor",lang2); //TODO: one 'useless' mentor-folder
+		path = g_strdup_printf("mentor_speech7_12/%s/mentor",lang_of_mentor); //TODO: one 'useless' mentor-folder
 	else
-		path = g_strdup_printf("mentor_speech/%s/mentor",lang2); //TODO: one 'useless' mentor-folder
+		path = g_strdup_printf("mentor_speech/%s/mentor",lang_of_mentor); //TODO: one 'useless' mentor-folder
+	g_free(lang_of_mentor);
 
 	message = g_strdup_printf("mentor language path='%s' ",path);
-	cem_add_to_log(message, J_LOG_DEBUG);
+	cem_add_to_log(message, J_LOG_INFO);
 	g_free(message);
 
 	jammo_mentor_set_language(jammo_mentor_get_default(),path);
