@@ -2,6 +2,7 @@
 #include "configure.h"
 #include <glib.h>
 #include <stdio.h>
+#include <fcntl.h> //we check some files
 
 static gchar* JAMMO_DIRECTORY=NULL;        //This is used on both games (e.g for log-files)
 static gchar* COMPOSITIONS_DIRECTORY=NULL; //3-6 composings
@@ -63,6 +64,31 @@ void configure_init_directories(gboolean small_game){
 	}
 
 	make_directory(LOG_DIRECTORY);
+
+	//Check jammo.config
+	gchar* setting_file = g_strdup_printf("%s/jammo.config",configure_get_jammo_directory());
+	int fd = open(setting_file,O_RDONLY);
+	if (fd == -1) //Settings-file not found => maybe first run
+		{
+			printf("Making default settings file '%s' for JamMo (maybe first run?)\n",setting_file);
+			FILE* ofp;
+			ofp = fopen(setting_file, "w");
+			fprintf(ofp,"{\n");
+			fprintf(ofp,"\"WRITE_LOG_ALSO_STDOUT\" : false,\n");
+			fprintf(ofp,"\"LOG_DEBUG\" : true,\n");
+			fprintf(ofp,"\"LOG_INFO\" : true,\n");
+			fprintf(ofp,"\"LOG_FATAL\" : true,\n");
+			fprintf(ofp,"\"LOG_ERROR\" : true,\n");
+			fprintf(ofp,"\"LOG_WARN\" : true,\n");
+			fprintf(ofp,"\"LOG_USER_ACTION\" : true,\n");
+			fprintf(ofp,"\"LOG_NETWORK\" : true,\n");
+			fprintf(ofp,"\"LOG_NETWORK_DEBUG\" : true,\n");
+			fprintf(ofp,"\"LOG_MENTOR_SPEECH\" : true,\n");
+			fprintf(ofp,"\"MENTOR_LANGUAGE\" : \"system\"\n");
+			fprintf(ofp,"}\n");
+			fclose(ofp);
+		}
+	g_free(setting_file);
 }
 
 void configure_release_directories(){
