@@ -199,7 +199,7 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				
-				logmsg = g_strdup_printf("bytes: %d [%d|%d|%d]", msg->length, ntohs(*(gint16*)&msg->message[0]),ntohl(*(gint32*)&msg->message[2]),ntohs(*(gint16*)&msg->message[6]));
+				logmsg = g_strdup_printf("bytes: %d [%d|%d|%d]", msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]));
 				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				
@@ -675,7 +675,7 @@ void gems_communication_process_new_rejected(gems_connection* element)
 	g_free(logmsg);
 }
 
-gboolean gems_communication_write_encrypted_data(gint16 type, gems_connection* element, gems_message* data)
+gboolean gems_communication_write_encrypted_data(guint16 type, gems_connection* element, gems_message* data)
 {
 	gboolean success = TRUE;
 	gems_message* envelope = gems_security_create_envelope(type, element, data);
@@ -747,14 +747,14 @@ gint gems_communication_process_connected()
 			if(gems_connection_partial_data_amount(element) > 0)
 			{
 				// If 2 bytes = Service id/packet type read -> read length
-				if(gems_connection_partial_data_amount(element) == sizeof(gint16))
+				if(gems_connection_partial_data_amount(element) == sizeof(guint16))
 				{
-					gint32 packetlength = -1;
+					guint32 packetlength = 0;
 					
-					switch ((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &packetlength, sizeof(gint32))))
+					switch ((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &packetlength, sizeof(guint32))))
 					{
 						/* CORRECT AMOUNT */
-						case sizeof(gint32):
+						case sizeof(guint32):
 							//TODO check that length is in limits
 							//printf("gems_communication_process_list: read length: %d", ntohl(packetlength));
 							gems_connection_add_32(element,packetlength); // Add length
@@ -773,14 +773,14 @@ gint gems_communication_process_connected()
 				}
 				
 				// If 6 bytes read = Service id and length read && Not authenticated -> read command
-				else if(gems_connection_partial_data_amount(element) == (sizeof(gint16) + sizeof(gint32)) &&
+				else if(gems_connection_partial_data_amount(element) == (sizeof(guint16) + sizeof(guint32)) &&
 					(element->connection_state == JAMMO_CONNECTED_NO_AUTH))
 				{
-					gint16 command = -1;
+					guint16 command = 0;
 					
-					switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &command, sizeof(gint16))))
+					switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &command, sizeof(guint16))))
 					{
-						case sizeof(gint16):
+						case sizeof(guint16):
 							//printf("gems_communication_process_list : command: %d, user in state: %d", ntohs(command), element->connection_state);
 							gems_connection_add_16(element,command);
 							break;
@@ -801,10 +801,10 @@ gint gems_communication_process_connected()
 				
 				// Authenticated, read 6 or more bytes -> read rest
 				else if(element->connection_state == JAMMO_CONNECTED_AUTH &&
-					(gems_connection_partial_data_amount(element) >= (sizeof(gint16) + sizeof(gint32))))
+					(gems_connection_partial_data_amount(element) >= (sizeof(guint16) + sizeof(guint32))))
 				{
 					// remaining = length - read bytes
-					gint remaining = ntohl(gems_connection_get_32(element, sizeof(gint16))) - gems_connection_partial_data_amount(element);
+					guint remaining = ntohl(gems_connection_get_32(element, sizeof(guint16))) - gems_connection_partial_data_amount(element);
 					gchar remainingdata[remaining];
 					memset(&remainingdata,'\0', remaining);
 					
@@ -836,7 +836,7 @@ gint gems_communication_process_connected()
 				}
 				
 				// All read? Data read = length parameter in buffer[2]
-				if(gems_connection_partial_data_amount(element) == ntohl(gems_connection_get_32(element,sizeof(gint16))))
+				if(gems_connection_partial_data_amount(element) == ntohl(gems_connection_get_32(element,sizeof(guint16))))
 				{
 					//printf("gems_communication_process_list: full packet received (%d bytes).", ntohl(gems_connection_get_32(element,sizeof(gint16))));
 					if(gems_communication_process_data(element) == FALSE)
@@ -847,7 +847,7 @@ gint gems_communication_process_connected()
 					}
 				}
 				
-				if(gems_connection_partial_data_amount(element) > ntohl(gems_connection_get_32(element,sizeof(gint16))))
+				if(gems_connection_partial_data_amount(element) > ntohl(gems_connection_get_32(element,sizeof(guint16))))
 				{					
 					logmsg = g_strdup_printf("gems_communication_process_list: more than full packet! ERROR?");
 					cem_add_to_log(logmsg, J_LOG_ERROR);
@@ -862,12 +862,12 @@ gint gems_communication_process_connected()
 			// No partial data - read first 16 bits
 			else
 			{
-				gint16 identifier = -1;
+				guint16 identifier = 0;
 			
-				switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &identifier, sizeof(gint16))))
+				switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &identifier, sizeof(guint16))))
 				{
 					/* CORRECT AMOUNT */
-					case sizeof(gint16):
+					case sizeof(guint16):
 						// Authenticated - expect a encrypted envelope
 						if(element->connection_state == JAMMO_CONNECTED_AUTH)
 						{
@@ -1037,7 +1037,7 @@ gboolean gems_communication_process_data(gems_connection* element)
 			success = FALSE; // TODO change to add a "invalid message" to errors
 			break;
 		case PROFILE_SERVICE_ID:
-			if(gems_connection_get_16(element,sizeof(gint16)+sizeof(gint32)) == PROFILE_ENC)
+			if(gems_connection_get_16(element,sizeof(guint16)+sizeof(guint32)) == PROFILE_ENC)
 			{
 				// If the message cannot be processed it from some one else than teacher
 				if(!gems_service_profile_process_profile_upload(element))
@@ -1218,7 +1218,7 @@ void gems_communication_process_error(gems_connection* element)
 										{
 											if(gems_get_data()->profile_request_timeout_sid != 0) g_source_remove(gems_get_data()->profile_request_timeout_sid);
 											if(gems_get_data()->teacher_profile_request_timer) g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
-											gems_unset_waiting_for_teacher();
+											gems_unset_waiting_profile_from_teacher();
 										
 											cem_add_to_log("gems_communication_process_error: No profile for requested username on teacher server",J_LOG_NETWORK_DEBUG);
 										
@@ -1658,6 +1658,18 @@ gboolean gems_communication_do_profile_request_to_teacher(gchar* username)
 	return rval;
 }
 
+gboolean gems_communication_send_profile_to_teacher()
+{
+	if(gems_teacher_connection_is_connected())
+	{
+		gems_message* msg = gems_create_message_service_profile(PROFILE_FULL);
+		gboolean rval = gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,msg);
+		gems_clear_message(msg);
+		return rval;
+	}
+	else return FALSE;
+}
+
 gint gems_communication_search_teacher()
 {
 	gchar* logmsg = NULL;
