@@ -60,7 +60,7 @@ void gems_communication_process_new(gems_connection* element);
 void gems_communication_process_new_rejected(gems_connection* element);
 
 // Write data as envelope to element
-gboolean gems_communication_write_encrypted_data(gint16 type, gems_connection* element, gems_message* data);
+gboolean gems_communication_write_encrypted_data(guint16 type, gems_connection* element, gems_message* data);
 
 // Write message to socket
 gint gems_communication_write_data(gint socket, gems_message* data);
@@ -76,6 +76,7 @@ gboolean gems_teacher_connection_disconnect();
 void gems_clear_teacher_connection();
 
 gboolean gems_communication_do_profile_request_to_teacher(gchar* username);
+gboolean gems_communication_send_profile_to_teacher();
 gint gems_communication_search_teacher();
 
 #endif  /* _COMMUNICATION_H_ */
