@@ -57,6 +57,7 @@ gems_components* gems_get_data()
 		gems_data->profile_request_timeout_sid = 0;
 		gems_data->teacher_profile_requests = 0;
 		gems_data->waiting_for_teacher = FALSE;
+		gems_data->waiting_profile_from_teacher = FALSE;
 		gems_data->username_to_login = NULL;
 	}
 	return gems_data;
@@ -89,7 +90,7 @@ gems_communication_data* gems_get_communication()
 
 gems_security_context* gems_get_security_contexts()
 {
-	return gems_data->security_context;
+	return gems_get_data()->security_context;
 }
 
 gems_service_jammo* gems_get_service_jammo()
@@ -153,12 +154,27 @@ void gems_unset_waiting_for_teacher()
 {
 	// TODO call CHUM to "remove curtain"
 	gems_get_data()->waiting_for_teacher = FALSE;
+}
+
+gboolean gems_is_waiting_profile_from_teacher()
+{
+	return gems_get_data()->waiting_profile_from_teacher;
+}
+
+void gems_set_waiting_profile_from_teacher()
+{
+	gems_get_data()->waiting_profile_from_teacher = TRUE;
+}
+
+void gems_unset_waiting_profile_from_teacher()
+{
+	gems_get_data()->waiting_profile_from_teacher = FALSE;
 	gems_reset_teacher_profile_request_counter();
 }
 
-void gems_unset_teacher_timeout_sid(gpointer param)
+void gems_unset_teacher_profile_timeout_sid(gpointer param)
 {
-	cem_add_to_log("Unset teacher timeout",J_LOG_NETWORK_DEBUG);
+	cem_add_to_log("Unset teacher profile timeout",J_LOG_NETWORK_DEBUG);
 	gems_get_data()->profile_request_timeout_sid = 0;
 	gems_reset_teacher_profile_request_counter();
 }
@@ -499,6 +515,18 @@ GList* gems_list_jammo_connections()
 	}
 }
 
+// Get a connection with selected user id
+gems_connection* gems_get_connection_with_user_id(guint32 userid)
+{
+	gems_components* data = gems_get_data();
+	
+	if(data == NULL) return NULL;
+	if(data->communication == NULL) return NULL;
+	if(data->communication->connections == NULL) return NULL;
+	
+	return gems_communication_get_connection_with_userid(data->communication->connections,userid);
+}
+
 // Get pointer to profile of an connection element
 gems_peer_profile* gems_get_profile(gems_connection* element)
 {
