@@ -14,6 +14,8 @@
 #include "../cem/cem.h"
 
 #include "gems_teacher_server_utils.h"
+#include "gems_message_functions.h"
+#include "gems.h"
 
 // Login
 gboolean gems_profile_manager_login(guint32 userId, gchar* username, gchar* passworddata)
@@ -191,7 +193,7 @@ gint gems_profile_manager_set_user(gchar* username)
 				(gems_communication_do_profile_request_to_teacher(gems_get_login_username())))
 			{
 				// set waiting for teacher - no logins should be possible!
-				gems_set_waiting_for_teacher();
+				gems_set_waiting_profile_from_teacher();
 				gems_increase_teacher_profile_request_counter();
 				
 				// restart timer
@@ -201,7 +203,7 @@ gint gems_profile_manager_set_user(gchar* username)
 				if(gems_get_data()->profile_request_timeout_sid == 0)
 				{
 					gems_get_data()->profile_request_timeout_sid = 
-						g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_profile_manager_set_user, NULL, gems_unset_teacher_timeout_sid);
+						g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_profile_manager_set_user, NULL, gems_unset_teacher_profile_timeout_sid);
 				}
 				return CHANGE_USER_WAITING_PROFILE; // Equals TRUE, the timed function remains
 			}
@@ -230,7 +232,7 @@ gint gems_profile_manager_set_user(gchar* username)
 		else
 		{
 			// Allow to continue
-			gems_unset_waiting_for_teacher();
+			gems_unset_waiting_profile_from_teacher();
 			
 			// Destroy timer and set to NULL
 			if(gems_get_data()->teacher_profile_request_timer)
@@ -238,7 +240,6 @@ gint gems_profile_manager_set_user(gchar* username)
 				g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
 				gems_get_data()->teacher_profile_request_timer = NULL;
 			}
-			gems_reset_teacher_profile_request_counter();
 			
 			// Equals to FALSE (0) so the timeout function should be removed
 			return CHANGE_USER_OK;
@@ -266,14 +267,42 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 		guchar* passhash = gems_security_calculate_hash(passwd,&hashlen);
 		if(hashlen != SHA_HASH_LENGTH) cem_add_to_log("Next authentication might fail, password hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 		
-		// TODO encrypt new password with current context
-		//guint encnewpwlen = strlen(passworddata);
-		//guchar* encnewpw = gems_security_encrypt_data((guchar*)passworddata,&encnewpwlen);
+		// encrypt new password with current context
+		guint newpasshashlen = strlen(passworddata)+1;
+		guint newpasslen = strlen(passworddata)+1;
 		
-		// TODO decrypt the password
+		guchar* newpass_hash = gems_security_calculate_hash((guchar*)passworddata,&newpasshashlen);
+		if(newpasshashlen != SHA_HASH_LENGTH) cem_add_to_log("Profile password might not be set correctly to teacher server, password hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 		
-		// TODO hash decrypted and compare hashes
+		guchar* pwdata = NULL;
+		guint pwdatalen = newpasslen;
+		if(newpasslen < AES_BLOCK_SIZE)	pwdata = (guchar*)g_malloc0(sizeof(guchar*)*AES_BLOCK_SIZE);
+		else pwdata = (guchar*)g_malloc0(sizeof(guchar*)*newpasslen);
 		
+		g_memmove(pwdata,passworddata,newpasslen);
+		
+		// Pad
+		if(newpasslen < AES_BLOCK_SIZE)
+		{
+			pwdatalen = AES_BLOCK_SIZE;
+			memset(&pwdata[newpasslen],'_',AES_BLOCK_SIZE-newpasslen);
+		}
+		
+		// Encrypt pass
+		guchar* newpass_enc = gems_security_encrypt_data(pwdata,&pwdatalen);
+		guint newpass_enclen = pwdatalen;
+
+		// decrypt pass
+		guchar* newpass_dec = gems_security_decrypt_data(newpass_enc,&newpass_enclen);
+		newpasshashlen = newpass_enclen;
+		
+		guchar* newpass_dec_real = (guchar*)g_malloc0(sizeof(guchar*)*newpasslen);
+		g_memmove(newpass_dec_real,newpass_dec,newpasslen);
+		guint newpass_real_len = newpasslen;
+		
+		// hash decrypted and compare hashes
+		guchar* newpass_dechash = gems_security_calculate_hash(newpass_dec_real,&newpass_real_len);
+		if(newpass_real_len != SHA_HASH_LENGTH) cem_add_to_log("Profile password might not be set correctly to teacher server, decrypted password hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 		
 		// Set new security contexts
 		gems_security_change_password(passwd,salt);
@@ -318,19 +347,49 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 				}
 				
 				// TODO Send passhash + encnewpw to teacher if teacher is present
-				// TODO If no teacher, the encnewpw (+ its length) should be saved somewhere for sending it later!
+				if(gems_security_verify_hash(newpass_hash,newpass_dechash,SHA_HASH_LENGTH))
+				{
+					if(gems_teacher_connection_is_connected())
+					{
+						if(newpasslen > G_MAXUINT8) cem_add_to_log("Password length is more than max for guint8!.",J_LOG_ERROR);
+						
+						gems_message *pwcmsg = gems_create_message_password_changed(newpass_hash,newpass_enc,pwdatalen,(guint8)newpasslen);
+						if(pwcmsg)
+						{
+							if(!gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,pwcmsg))
+							{
+								cem_add_to_log("Password change cannot be sent. Invalid write.",J_LOG_ERROR);
+								// TODO resend?
+							}
+							else cem_add_to_log("Password change sent succesfully!",J_LOG_INFO);
+							gems_clear_message(pwcmsg);
+						}
+					}
+					// TODO If no teacher, the encnewpw (+ its length) should be saved somewhere for sending it later!
+					else cem_add_to_log("Password change cannot be sent, no teacher present.",J_LOG_INFO);
+					
+				}
+				else cem_add_to_log("Errors while creating password to be sent to teacher, hashes do not match.",J_LOG_ERROR);
+				
 			}
 			else
 			{
 				rval = FALSE;
 				cem_add_to_log("Errors while encrypting profile with new password!", J_LOG_ERROR);
 			}
-			
+			if(pwdata) g_free(pwdata);
+			if(newpass_hash) g_free(newpass_hash);
+			if(newpass_enc) g_free(newpass_enc);
+			if(newpass_dec) g_free(newpass_dec);
+			if(newpass_dec_real) g_free(newpass_dec_real);
+			if(newpass_dechash) g_free(newpass_dechash);
+		
 			if(profile != NULL) g_free(profile);
 			if(profilehash != NULL) g_free(profilehash);
 			if(encrypted != NULL) g_free(encrypted);
 			if(decrypted != NULL) g_free(decrypted);
 			if(decryptedhash != NULL) g_free(decryptedhash);
+			
 		}
 		else
 		{
@@ -341,7 +400,6 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 		if(salt != NULL) g_free(salt);
 		if(passwd != NULL) g_free(passwd);
 		if(passhash != NULL) g_free(passhash);
-		//if(encnewpw != NULL) g_free(encnewpw);
 	}
 	// Not authenticated
 	else
@@ -359,7 +417,7 @@ gboolean gems_profile_manager_create_default_user_profile(gchar* passworddata, g
 	GRand* grand = g_rand_new_with_seed(time(NULL));
 	
 	// Create profile with default informationm, except id (random), password (given) and age (given)
-	jammo_profile_container* profile = gems_teacher_server_create_profile(g_rand_int(grand),"defaultuser",passworddata,"none","FirstName","LastName",age,0);
+	jammo_profile_container* profile = gems_teacher_server_create_profile(g_rand_int(grand),"defaultuser",passworddata,"none","FirstName","LastName",age,PROF_DEFAULT_AVATARID);
 
 	if(profile)
 	{
@@ -385,9 +443,13 @@ gboolean gems_profile_manager_logout()
 	
 	/* TODO add checks for each call (for NULL's) */
 	 
-	// Is it necessary to save profile
+	// Saving and updating can be done as authenticated
 	if(profilemanager_is_authenticated(pm))
 	{
+		// Send profile to teacher
+		if(gems_communication_send_profile_to_teacher()) cem_add_to_log("Profile updated to teacher server",J_LOG_DEBUG);
+		
+		// Is it necessary to save profile
 		if(profilemanager_is_saving_required(pm))
 		{
 			// Get all profile information to one line
@@ -503,7 +565,7 @@ guint32 gems_profile_manager_get_avatar_id(gems_peer_profile* profile)
 	if(profile == NULL)
 	{
 		ProfileManager* pm = gems_get_data()->pm;
-		if(pm == NULL) return 0;
+		if(pm == NULL) return PROF_DEFAULT_AVATARID;
 		return profilemanager_get_avatarid(pm);
 	}
 	else return profile->avatarid;
@@ -547,7 +609,7 @@ void gems_profile_manager_reset_points()
 	if(pm != NULL) profilemanager_reset_points(pm);
 }
 
-gems_peer_profile* gems_profile_get_profile_of_user(guint32 id)
+gems_peer_profile* gems_profile_manager_get_profile_of_user(guint32 id)
 {
 	if(gems_get_data()->communication == NULL) return NULL; // Communication not initialized
 	gems_connection* element = gems_communication_get_connection_with_userid(gems_get_data()->communication->connections,id);
