@@ -33,6 +33,8 @@ gint gems_profile_manager_authenticate_default_user(gchar* passworddata);
 
 gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata);
 
+gint gems_profile_manager_set_user(gchar* username);
+
 gboolean gems_profile_manager_change_password(gchar* passworddata);
 
 gboolean gems_profile_manager_create_default_user_profile(gchar* passworddata, guint16 age);
@@ -126,5 +128,6 @@ gboolean gems_profile_manager_remove_points(guint32 _value);
 void gems_profile_manager_reset_points();
 
 gboolean gems_profile_manager_is_authenticated();
+gchar* gems_profile_manager_get_loaded_username();
 
 #endif
