@@ -96,18 +96,20 @@ void gems_service_control_handle_control_mode(gems_components* data, gems_connec
 {
 	gchar* logmsg = NULL;
 	guint position=8;
-	gint16 cntrl_type;
-	gint16 lock_mode;
+	guint16 cntrl_type;
+	guint16 lock_mode;
 
 	// Control type
 	cntrl_type = gems_connection_get_16(element,position);
-	position = position + sizeof(gint16);
+	position = position + sizeof(guint16);
 
 	// Lock mode
 	lock_mode = gems_connection_get_16(element,position);
-	position = position + sizeof(gint16);
+	position = position + sizeof(guint16);
 
 	// TODO do something with new control mode
+	// TODO use gems_set_waiting_for_teacher() when lock_mode == lock
+	// TODO use gems_unset_waiting_for_teacher() when lock_mode == unlock
 
 	logmsg = g_strdup_printf("gems_service_control_handle_control_mode: got CONTROL_MODE ");
 	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
@@ -126,36 +128,43 @@ void gems_service_control_handle_control_ok(gems_components* data, gems_connecti
 void gems_service_control_handle_set_login(gems_components* data, gems_connection* element)
 {
 	gchar* logmsg = NULL;
-	gint position = sizeof(gint16)+sizeof(gint32)+sizeof(gint16);
-	gint length = gems_connection_get_32(element,sizeof(gint16)) - position; // length - header
+	guint position = sizeof(guint16)+sizeof(guint32)+sizeof(guint16);
+	guint32 length = gems_connection_get_32(element,sizeof(guint16)) - position; // length - header
 	
 	gchar* loginname = gems_connection_get_data(element,position,length);
 	
-	logmsg = g_strdup_printf("gems_service_control_handle_set_login: username \"%s\" will be used as login name.",loginname);
-	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
-	g_free(logmsg);
+	// TODO if logged in, logout the user AND INFORM ! -> CALLBACK TO CHUM? Return to login screen and stop all activity?
+	// if(gems_profile_manager_logout()) cem_add_to_log("gems_service_control_handle_set_login: logged out previous user",J_LOG_DEBUG);
 	
-	// if logged in, logout the user
-	if(gems_profile_manager_logout()) cem_add_to_log("gems_service_control_handle_set_login: logged out previous user",J_LOG_DEBUG);
-	
-	// load profile with loginname
-	switch(gems_profile_manager_set_user(loginname))
+	if(!gems_profile_manager_is_authenticated())
 	{
-		// Found & loaded
-		case CHANGE_USER_OK:
-			cem_add_to_log("gems_service_control_handle_set_login: profile found",J_LOG_DEBUG);
-			break;
-		// Not found but request sent
-		case CHANGE_USER_WAITING_PROFILE:
-			cem_add_to_log("gems_service_control_handle_set_login: profile requested.",J_LOG_DEBUG);
-			break;
-		// Should not happen!
-		case CHANGE_USER_NO_USERNAME:
-			cem_add_to_log("gems_service_control_handle_set_login: teacher sent username as NULL.",J_LOG_DEBUG);
-			break;
-		default:
-			break;
+		logmsg = g_strdup_printf("gems_service_control_handle_set_login: username \"%s\" will be used as login name.",loginname);
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+		g_free(logmsg);
+		
+		// load profile with loginname
+		switch(gems_profile_manager_set_user(loginname))
+		{
+			// Found & loaded
+			case CHANGE_USER_OK:
+				cem_add_to_log("gems_service_control_handle_set_login: profile found",J_LOG_DEBUG);
+				break;
+			// Not found but request sent
+			case CHANGE_USER_WAITING_PROFILE:
+				cem_add_to_log("gems_service_control_handle_set_login: profile requested.",J_LOG_DEBUG);
+				break;
+			// Should not happen!
+			case CHANGE_USER_NO_USERNAME:
+				cem_add_to_log("gems_service_control_handle_set_login: teacher sent username as NULL.",J_LOG_DEBUG);
+				break;
+			default:
+				break;
+		}
+	}
+	else
+	{
+		gems_set_login_username(loginname);
+		cem_add_to_log("gems_service_control_handle_set_login: user logged in, the username will be changed after logout",J_LOG_DEBUG);
 	}
-	
 	g_free(loginname);
 }
