@@ -823,8 +823,8 @@ void gems_service_group_handle_member_list(gems_components* data, gems_connectio
 		if(element->profile->id == data->service_group->group_info->owner)
 		{
 			data->service_group->group_info->peers[0] = gems_connection_get_32(element,12); // Group owner is a peer
-			gint i = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + sizeof(guint32) + sizeof(guint32); // 16
-			gint pos = 1;
+			guint i = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint32) + sizeof(guint32); // 16
+			guint pos = 1;
 			gboolean ownfound = FALSE;
 			while((i < 28) && (pos < (GROUP_MAX_SIZE - 1)))
 			{
