@@ -47,8 +47,8 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 	gems_connection* element = NULL;
 	GList* iterator = NULL;
 	GList* tempiter = NULL;
-	gint bytesread = -1;
-	gint32 dataleft = 0;
+	guint32 bytesread = 0;
+	guint32 dataleft = 0;
 	gchar* msgdata = NULL;
 	gchar* logmsg = NULL;
 	
@@ -70,14 +70,14 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 			if(gems_connection_partial_data_amount(element) > 0)
 			{
 				// If 2 bytes = Service id or error read -> read length
-				if(gems_connection_partial_data_amount(element) == sizeof(gint16))
+				if(gems_connection_partial_data_amount(element) == sizeof(guint16))
 				{
-					gint32 packetlength = -1;
+					guint32 packetlength = 0;
 					
-					switch ((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &packetlength, sizeof(gint32))))
+					switch ((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &packetlength, sizeof(guint32))))
 					{
 						/* CORRECT AMOUNT */
-						case sizeof(gint32):
+						case sizeof(guint32):
 							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): read length: %d", (service == TRUE ? 's' : 'c'), ntohl(packetlength));
 							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
@@ -97,13 +97,13 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 				}
 				
 				// If 6 bytes read = Service id and length read -> read command or service id (error)
-				else if(gems_connection_partial_data_amount(element) == (sizeof(gint16) + sizeof(gint32)))
+				else if(gems_connection_partial_data_amount(element) == (sizeof(guint16) + sizeof(guint32)))
 				{
-					gint16 command = -1;
+					guint16 command = 0;
 					
-					switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &command, sizeof(gint16))))
+					switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &command, sizeof(guint16))))
 					{
-						case sizeof(gint16):
+						case sizeof(guint16):
 							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): command: %d, user in state: %d",
 								(service == TRUE ? 's': 'c'), ntohs(command), element->connection_state);
 							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
@@ -125,17 +125,17 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 				}
 				
 				// If 8 bytes read and there is data to read
-				else if((gems_connection_partial_data_amount(element) == (sizeof(gint16) + sizeof(gint32) + sizeof(gint16))) &&
-					(gems_connection_partial_data_amount(element) != gems_connection_get_32(element,sizeof(gint16))))
+				else if((gems_connection_partial_data_amount(element) == (sizeof(guint16) + sizeof(guint32) + sizeof(guint16))) &&
+					(gems_connection_partial_data_amount(element) != gems_connection_get_32(element,sizeof(guint16))))
 				{
-					dataleft = gems_connection_get_32(element, sizeof(gint16)) - (sizeof(gint16) + sizeof(gint32) + sizeof(gint16));
-					gint16 errortype = 0;
+					dataleft = gems_connection_get_32(element, sizeof(guint16)) - (sizeof(guint16) + sizeof(guint32) + sizeof(guint16));
+					guint16 errortype = 0;
 					
 					// error message
 					if(gems_connection_get_16(element,0) == ERROR_MSG)
 					{
 						// Read the error type
-						if((bytesread	= gems_communication_read_data(ph_c_connection_get_fd(element->connection), &errortype, sizeof(gint16))) == sizeof(gint16))
+						if((bytesread	= gems_communication_read_data(ph_c_connection_get_fd(element->connection), &errortype, sizeof(guint16))) == sizeof(guint16))
 						{
 							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): error type = %d, bytesread = %d, dataleft = %d",
 								(service == TRUE ? 's' : 'c'), ntohs(errortype), bytesread, dataleft);
@@ -192,7 +192,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 				else
 				{
 					// left = packet length - read amount
-					dataleft = gems_connection_get_32(element, sizeof(gint16)) - gems_connection_partial_data_amount(element);
+					dataleft = gems_connection_get_32(element, sizeof(guint16)) - gems_connection_partial_data_amount(element);
 					msgdata = (gchar*)g_malloc(sizeof(gchar*) * dataleft);
 					memset(msgdata,'\0',dataleft);
 					
@@ -217,10 +217,10 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 				}
 				
 				// All read? Data read = length parameter in buffer[2]
-				if(gems_connection_partial_data_amount(element) == gems_connection_get_32(element,sizeof(gint16)))
+				if(gems_connection_partial_data_amount(element) == gems_connection_get_32(element,sizeof(guint16)))
 				{
 					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): full packet received (%d bytes).",
-						(service == TRUE ? 's': 'c'),gems_connection_get_32(element,sizeof(gint16)));
+						(service == TRUE ? 's': 'c'),gems_connection_get_32(element,sizeof(guint16)));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					
@@ -254,12 +254,12 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 			// No partial data - read service id
 			else
 			{
-				gint16 serviceid = -1;
+				guint16 serviceid = 0;
 			
-				switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &serviceid, sizeof(gint16))))
+				switch((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection), &serviceid, sizeof(guint16))))
 				{
 					/* CORRECT AMOUNT */
-					case sizeof(gint16):
+					case sizeof(guint16):
 						if((ntohs(serviceid) == JAMMO_SERVICE_ID) || (ntohs(serviceid) == ERROR_MSG))
 						{
 							gems_connection_add_16(element, ntohs(serviceid));
@@ -352,7 +352,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 			if(service == FALSE) break; // In client mode this state should be never active
 			
 			// Command is CONNECT_REQ
-			if(gems_connection_get_16(element,(sizeof(gint16) + sizeof(gint32))) == CONNECT_REQ)
+			if(gems_connection_get_16(element,(sizeof(guint16) + sizeof(guint32))) == CONNECT_REQ)
 			{
 				gems_message* msg = gems_create_message_service_jammo(VERSION_REQ);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
@@ -366,7 +366,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 				else
 				{
 					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d]", (service == TRUE ? 's': 'c'),
-						msg->length, ntohs(*(gint16*)&msg->message[0]),ntohl(*(gint32*)&msg->message[2]),ntohs(*(gint16*)&msg->message[6]));
+						msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 							
@@ -383,10 +383,10 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 		
 		case JAMMO_WAITING_VERSION:
 			// Command is VERSION_REPLY
-			if(gems_connection_get_16(element,(sizeof(gint16) + sizeof(gint32))) == VERSION_REPLY)
+			if(gems_connection_get_16(element,(sizeof(guint16) + sizeof(guint32))) == VERSION_REPLY)
 			{
 				// TODO check the versions!
-				if(g_strcmp0(gems_connection_get_char(element, (sizeof(gint16) + sizeof(gint32) + sizeof(gint16))),VERSION) == 0)
+				if(g_strcmp0(gems_connection_get_char(element, (sizeof(guint16) + sizeof(guint32) + sizeof(guint16))),VERSION) == 0)
 				{
 					gems_message* msg = gems_create_message_service_jammo(CONNECT_REPLY);
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
@@ -400,7 +400,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 					else
 					{
 						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d]", (service == TRUE ? 's': 'c'),
-							msg->length, ntohs(*(gint16*)&msg->message[0]),ntohl(*(gint32*)&msg->message[2]),ntohs(*(gint16*)&msg->message[6]));
+							msg->length, g_ntohs(*(guint16*)&msg->message[0]),g_ntohl(*(guint32*)&msg->message[2]),g_ntohs(*(guint16*)&msg->message[6]));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						
@@ -447,7 +447,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 			
 		case JAMMO_WAITING_REQUEST:
 			// Command is VERSION_REQ
-			if(gems_connection_get_16(element,(sizeof(gint16) + sizeof(gint32))) == VERSION_REQ)
+			if(gems_connection_get_16(element,(sizeof(guint16) + sizeof(guint32))) == VERSION_REQ)
 			{
 				gems_message* msg = gems_create_message_service_jammo(VERSION_REPLY);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
@@ -460,7 +460,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 				else
 				{
 					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d|%s]", (service == TRUE ? 's': 'c'),
-						msg->length, ntohs(*(gint16*)&msg->message[0]),ntohl(*(gint32*)&msg->message[2]),ntohs(*(gint16*)&msg->message[6]), &msg->message[8]);
+						msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]), &msg->message[8]);
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					
@@ -476,7 +476,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 			
 		case JAMMO_WAITING_REPLY:
 			// Command is CONNECT_REPLY
-			if(gems_connection_get_16(element,(sizeof(gint16) + sizeof(gint32))) == CONNECT_REPLY)
+			if(gems_connection_get_16(element,(sizeof(guint16) + sizeof(guint32))) == CONNECT_REPLY)
 			{
 				if(service == TRUE)
 				{
@@ -498,7 +498,7 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 					else
 					{
 						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d]", (service == TRUE ? 's': 'c'), 
-							msg->length, ntohs(*(gint16*)&msg->message[0]),ntohl(*(gint32*)&msg->message[2]),ntohs(*(gint16*)&msg->message[6]));
+							msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						
@@ -546,13 +546,13 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 {
 	gems_components* data = gems_get_data();
 	gboolean success = TRUE;
-	gint16 errortype = 0;
+	guint16 errortype = 0;
 	gchar* logmsg = NULL;
 	
 	// Check what service sent
-	if(gems_connection_get_16(element, (sizeof(gint16)+sizeof(gint32))) == JAMMO_SERVICE_ID)
+	if(gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32))) == JAMMO_SERVICE_ID)
 	{
-		switch((errortype = gems_connection_get_16(element, (sizeof(gint16)+sizeof(gint32)+sizeof(gint16)))))
+		switch((errortype = gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32)+sizeof(guint16)))))
 		{
 			case ERROR_ALREADY_CONNECTED_TYPE:
 				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_ALREADY_CONNECTED");
@@ -595,7 +595,7 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 	}
 	else
 	{
-		logmsg = g_strdup_printf("gems_service_jammo_process_error: unexpected service type: %d", gems_connection_get_16(element, (sizeof(gint16)+sizeof(gint32))));
+		logmsg = g_strdup_printf("gems_service_jammo_process_error: unexpected service type: %d", gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32))));
 		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		// TODO send invalid service id ?
