@@ -152,7 +152,7 @@ double gems_connection_get_last_action(gems_connection* element)
 void gems_connection_add_16(gems_connection* element, guint16 value)
 {
 	// TODO report / handle if buffer exceeded
-	if((element->add_position + sizeof(gint16)) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
+	if((element->add_position + sizeof(guint16)) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
 	*(guint16*)&element->nwbuffer[element->add_position] = value;
 	element->add_position = element->add_position + sizeof(guint16);
@@ -190,7 +190,7 @@ void gems_connection_add_float(gems_connection* element, gfloat value)
 }
 
 // Add characters to network buffer, define need for padding with last value (pad)
-void gems_connection_add_char(gems_connection* element, gchar* value, gint length, gboolean pad)
+void gems_connection_add_char(gems_connection* element, gchar* value, guint length, gboolean pad)
 {
 	// TODO report / handle if buffer exceeded
 	if((element->add_position + length) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
@@ -212,7 +212,7 @@ void gems_connection_add_padding(gems_connection* element)
 }
 
 // Add data to the end of nwbuffer
-void gems_connection_add_data(gems_connection* element, gchar* data, gint length)
+void gems_connection_add_data(gems_connection* element, gchar* data, guint length)
 {
 	if(element->add_position + length >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
@@ -221,7 +221,7 @@ void gems_connection_add_data(gems_connection* element, gchar* data, gint length
 }
 
 // Get 16 bit integer from position
-guint16 gems_connection_get_16(gems_connection* element, gint from)
+guint16 gems_connection_get_16(gems_connection* element, guint from)
 {
 	if(from > element->add_position) return 0;
 	
@@ -229,7 +229,7 @@ guint16 gems_connection_get_16(gems_connection* element, gint from)
 }
 
 // Get 32 bit integer from position
-guint32 gems_connection_get_32(gems_connection* element, gint from)
+guint32 gems_connection_get_32(gems_connection* element, guint from)
 {
 	if(from > element->add_position) return 0;
 	
@@ -237,7 +237,7 @@ guint32 gems_connection_get_32(gems_connection* element, gint from)
 }
 
 // Get 64 bit integer from position
-guint64 gems_connection_get_64(gems_connection* element, gint from)
+guint64 gems_connection_get_64(gems_connection* element, guint from)
 {
 	if(from > element->add_position) return 0;
 	
@@ -245,7 +245,7 @@ guint64 gems_connection_get_64(gems_connection* element, gint from)
 }
 
 // Get 32 bit float from position
-gfloat gems_connection_get_float_for_localization(gems_connection* element, gint from)
+gfloat gems_connection_get_float_for_localization(gems_connection* element, guint from)
 {
 	gfloat ret;
 	guint32 value;
@@ -260,7 +260,7 @@ gfloat gems_connection_get_float_for_localization(gems_connection* element, gint
 }
 
 // Get 32 bit float from position
-gfloat gems_connection_get_float(gems_connection* element, gint from)
+gfloat gems_connection_get_float(gems_connection* element, guint from)
 {
 	gfloat value;
 
@@ -272,14 +272,14 @@ gfloat gems_connection_get_float(gems_connection* element, gint from)
 }
 
 // Get characters from position until next NULL character
-gchar* gems_connection_get_char(gems_connection* element, gint from)
+gchar* gems_connection_get_char(gems_connection* element, guint from)
 {
 	// TODO do a real check - copy until \0 character is found !
 	return (gchar*)&element->nwbuffer[from];
 }
 
 // Get data as chars from position until lenght is reached. Returns new gchar pointer, remember to free.
-gchar* gems_connection_get_data(gems_connection* element, gint from, gint length)
+gchar* gems_connection_get_data(gems_connection* element, guint from, guint length)
 {
 	gchar* buffer = (gchar*)g_malloc(sizeof(gchar*)*length);
 	memset(buffer,'\0',length);
@@ -290,14 +290,14 @@ gchar* gems_connection_get_data(gems_connection* element, gint from, gint length
 }
 
 // Copies the content in newcontent to nwbuffer of element
-void gems_connection_set_content(gems_connection* element, gchar* newcontent, gint length)
+void gems_connection_set_content(gems_connection* element, gchar* newcontent, guint length)
 {
 	gems_connection_clear_buffer(element);
 	memcpy(&element->nwbuffer,newcontent,length);
 }
 
 // Get the amount of partial data in the buffer
-gint gems_connection_partial_data_amount(gems_connection* element)
+guint gems_connection_partial_data_amount(gems_connection* element)
 {
 	return element->add_position;
 }
@@ -426,6 +426,9 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					break;
 				case PROFILE_SET_UNAME:
 					break;
+				case PROFILE_PASSCHANGED:
+					// Userid
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
 				default:
 					break;
 			}
