@@ -29,7 +29,7 @@ jammo_profile_container* gems_teacher_server_new_profile_container()
 	container->authlevel = NULL;
 	container->age = 0;
 	container->points = 0;
-	container->avatarid = 0;
+	container->avatarid = PROF_DEFAULT_AVATARID;
 	container->encrypted = NULL;
 	container->encrypted_length = 0;
 	return container;	
@@ -439,7 +439,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 	guint position = 0;
 	guint8 valuelength = 0;
 	
-	while(position <= length)
+	while(position < length)
 	{
 		// user id
 		id = *(guint32*)&serialized_data[position];
@@ -450,7 +450,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// username
-		username = (gchar*)g_malloc0(sizeof(gchar*)*valuelength);
+		username = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
 		g_memmove(username,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -459,7 +459,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// password
-		password = (gchar*)g_malloc0(sizeof(gchar*)*valuelength);
+		password = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
 		g_memmove(password,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -473,7 +473,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// firstname
-		firstname = (gchar*)g_malloc0(sizeof(gchar*)*valuelength);
+		firstname = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
 		g_memmove(firstname,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -482,7 +482,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// lastname
-		lastname = (gchar*)g_malloc0(sizeof(gchar*)*valuelength);
+		lastname = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
 		g_memmove(lastname,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -491,7 +491,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// authlevel
-		authlevel = (gchar*)g_malloc0(sizeof(gchar*)*valuelength);
+		authlevel = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
 		g_memmove(authlevel,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -654,13 +654,14 @@ gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data,
 					gems_teacher_server_clear_profile_list(data->profiles);
 					data->profiles = NULL;
 				}
+				// Clear own security contexts BEFORE deserializing profiles
+				gems_security_clear_security();
 				// deserialize
 				data->profiles = gems_teacher_server_deserialize_profiles(data->profiles,(gchar*)decrypted,data->datalength);
 			}
 			else rval = FALSE;
 		}
 		else rval = FALSE;
-		gems_security_clear_security();
 	}
 	else rval = FALSE;
 	
