@@ -14,7 +14,7 @@
 #include <glib.h>
 
 // Define illegal chars here
-#define ILLEGAL_CHARS ",.-_%&()[]/\\\'\"\n\t"
+#define ILLEGAL_CHARS ",;.:*-_!#£$%&{}()=[]+?/\\\'\"\n\t^~"
 #define ILLEGAL_CHAR_COUNT strlen(ILLEGAL_CHARS)
 
 /* Check if all characters are integers/digits
