@@ -7,6 +7,7 @@
 #include <unistd.h>
 
 #include "test-teacher-profile-service.h"
+#include "../../src/configure.h"
 
 volatile gboolean run = TRUE;
 volatile gboolean docleanup = FALSE;
@@ -103,6 +104,7 @@ gboolean process_data(gems_connection* c,serverdata* data)
 	// Localize data (network -> host), add new types to handle into localization func
 	gems_connection_localize_data_in_buffer(c);
 	gchar* log = NULL;
+	guint position = 0;
 	// Process packet, check the service id [first 2 bytes]
 	switch(gems_connection_get_16(c,0))
 	{
@@ -143,20 +145,27 @@ gboolean process_data(gems_connection* c,serverdata* data)
 						}
 					}
 					gems_clear_message(msg);
-					// TODO add sending of error message "profile not found"
 				}
 				else
 				{
 					log = g_strdup_printf("No profile found for username \"%s\"",username);
 					cem_add_to_log(log,J_LOG_INFO);
 					g_free(log);
+					
+					gems_message* errormsg = gems_create_error_message(ERROR_NO_PROFILE_FOR_USERNAME_TYPE,PROFILE_SERVICE_ID);
+					
+					if(gems_communication_write_data(ph_c_connection_get_fd(c->connection),errormsg) != errormsg->length)
+						cem_add_to_log("Cannot write ERROR_NO_PROFILE_FOR_USERNAME",J_LOG_ERROR);
+				
+					gems_clear_message(errormsg);
+					
 				}
 				g_free(username);
 			}
 			
 			else if(gems_connection_get_16(c,sizeof(gint16)+sizeof(gint32)) == PROFILE_FULL)
 			{
-				gint position = sizeof(gint16)+sizeof(gint32)+sizeof(gint16);
+				position = sizeof(gint16)+sizeof(gint32)+sizeof(gint16);
 			
 				gchar* username = gems_connection_get_char(c,position); // do not free, points to username in buffer!!
 				position = position + strlen(username) + 1;
@@ -198,6 +207,68 @@ gboolean process_data(gems_connection* c,serverdata* data)
 				}
 				else cem_add_to_log("Not a valid profile, ignoring",J_LOG_INFO);
 			}
+			else if (gems_connection_get_16(c,sizeof(gint16)+sizeof(gint32)) == PROFILE_PASSCHANGED)
+			{
+				cem_add_to_log("PROFILE_PASSCHANGED",J_LOG_INFO);
+				position = sizeof(guint16);
+				
+				guint32 length = gems_connection_get_32(c,position);
+				position = position + sizeof(guint32)+sizeof(guint16);
+				
+				guint32 uid = gems_connection_get_32(c,position);
+				position = position + sizeof(guint32);
+				
+				guint8 pwlen = *(guint8*)&c->nwbuffer[position];
+				position++;
+				
+				guchar* rechash = (guchar*)gems_connection_get_data(c,position,SHA_HASH_LENGTH);
+				position = position + SHA_HASH_LENGTH;
+				
+				guint passlength = length - position;
+				guchar* recnewencpass = (guchar*)gems_connection_get_data(c,position,passlength);
+				
+				jammo_profile_container* prof = gems_teacher_server_get_profile_for_user_id(data->database,uid);
+				
+				// found, update
+				if(prof)
+				{
+					guchar* passwd = gems_security_create_password(prof->password,prof->salt);
+					if(gems_security_init_security(passwd,prof->salt))
+					{
+						// decrypt new pass
+						guchar* decnewpass = gems_security_decrypt_data(recnewencpass,&passlength);
+						guint declength = passlength;
+						
+						gchar* newpass = (gchar*)g_malloc0(sizeof(gchar*)*pwlen);
+						g_memmove(newpass,decnewpass,pwlen);
+						guint newpasslen = pwlen;
+						
+						guchar* decnewpasshash = gems_security_calculate_hash((guchar*)newpass,&newpasslen);
+						
+						// compare hashes
+						if(gems_security_verify_hash(rechash,decnewpasshash,SHA_HASH_LENGTH))
+						{
+							log = g_strdup_printf("Password change received, old password = \"%s\", new password = \"%s\"",prof->password,decnewpass);
+							cem_add_to_log(log,J_LOG_INFO);
+							gems_security_clear_security();
+							if(gems_teacher_server_change_password(prof,newpass)) cem_add_to_log("Profile password updated.",J_LOG_INFO);
+							else cem_add_to_log("Error, cannot update profile password",J_LOG_ERROR);
+						}
+						else cem_add_to_log("Invalid password change",J_LOG_INFO);
+						
+						g_free(newpass);
+						g_free(decnewpass);
+						g_free(decnewpasshash);
+						
+						// TODO if hashes ok, clear security and initialize new with new password and encrypt profile
+					}
+					
+					g_free(passwd);
+				}
+				else cem_add_to_log("Error, no such user exists, discarding",J_LOG_ERROR);
+				g_free(rechash);
+				g_free(recnewencpass);
+			}
 			break;
 		case ERROR_MSG:
 			// TODO handle error messages
@@ -495,8 +566,8 @@ void create_profile_to_database(teacher_server_profile_data* data)
 	guint32 maxlen = strlen(maxlenstr);
 	gchar* avataridstring = (gchar*)g_malloc0(sizeof(gchar*)*maxlen);
 
-	guint32 avatarid = 0;
-	while(do_more)
+	guint32 avatarid = PROF_DEFAULT_AVATARID;
+	/*while(do_more)
 	{
 		printf("Avatar id (%u char max!): ",maxlen);
 		if(fgets(avataridstring,maxlen+1,stdin))
@@ -511,7 +582,7 @@ void create_profile_to_database(teacher_server_profile_data* data)
 			else memset(avataridstring,0,maxlen);
 		}
 	}
-	do_more = TRUE;
+	do_more = TRUE;*/
 
 	// Create profile
 	jammo_profile_container* profile = gems_teacher_server_create_profile(id,username,password,"none",firstname,lastname,age,avatarid);
@@ -543,6 +614,7 @@ int main(int argc,char* argv[])
 	gchar stdinput[100];
 	memset(&stdinput,0,100);
 	
+	configure_init_directories(FALSE);
 	cem_set_log_level(J_LOG_DEBUG+J_LOG_INFO+J_LOG_ERROR+J_LOG_NETWORK_DEBUG);
 	signal(SIGTERM,sighandler);
 	signal(SIGINT,sighandler);
@@ -564,7 +636,9 @@ int main(int argc,char* argv[])
 	cem_add_to_log("------------------------------------------------------------",J_LOG_INFO);
 	cem_add_to_log("Teacher profile service, press Ctrl+C to terminate.",J_LOG_INFO);
 	cem_add_to_log("Type \"add\" to enter new profile to database.", J_LOG_INFO);
-	cem_add_to_log("Type \"set\" to set a username to login for specific device.", J_LOG_INFO);
+	cem_add_to_log("Type \"set\" to set a username to login for specific client.", J_LOG_INFO);
+	cem_add_to_log("Type \"push\" to send a profile for specific client.", J_LOG_INFO);
+	cem_add_to_log("Type \"get\" to get a full profile from all clients.", J_LOG_INFO);
 	cem_add_to_log("------------------------------------------------------------",J_LOG_INFO);
 	
 	if(ph_c_init(data->ph,argc,argv) == TRUE)
@@ -613,8 +687,10 @@ int main(int argc,char* argv[])
 								
 								if(g_strcmp0(stdinput,"add") == 0) create_profile_to_database(data->database);
 								
-								if(g_strcmp0(stdinput,"set") == 0)
+								if((g_strcmp0(stdinput,"set") == 0) || (g_strcmp0(stdinput,"push") == 0))
 								{
+									gint type = (g_strcmp0(stdinput,"set") == 0) ? 0 : 1 ;
+									
 									if(g_list_length(data->clients) <= 0)
 									{
 										cem_add_to_log("no clients",J_LOG_INFO);
@@ -625,7 +701,7 @@ int main(int argc,char* argv[])
 									gchar tmpstr[12];
 									memset(&tmpstr,0,12);
 									
-									cem_add_to_log("Select a profile (give user id number)",J_LOG_INFO);
+									cem_add_to_log("Select a profile (give user id number or the username)",J_LOG_INFO);
 									
 									gems_teacher_server_print_profile_list(data->database->profiles);
 									
@@ -635,12 +711,17 @@ int main(int argc,char* argv[])
 									{
 										gems_erase_newline(tmpstr);
 										if(gems_all_integers(tmpstr)) pnmbr = (guint32)strtoul(tmpstr,NULL,10);
-										else break;
 									}
 									
 									// Get profile for id
-									jammo_profile_container* cont = gems_teacher_server_get_profile_for_user_id(data->database,pnmbr);
-									if(!cont) break;
+									jammo_profile_container* cont = NULL;
+									if(pnmbr != 0) cont = gems_teacher_server_get_profile_for_user_id(data->database,pnmbr);
+									else cont = gems_teacher_server_get_profile_for_user(data->database,tmpstr);
+									if(!cont)
+									{
+										cem_add_to_log("Not found, invalid id/username",J_LOG_INFO);
+										break;
+									}
 									
 									cem_add_to_log("Selected profile:",J_LOG_INFO);
 									gems_teacher_server_print_profile(cont);
@@ -667,15 +748,18 @@ int main(int argc,char* argv[])
 									}
 									
 									// Create message
-									gems_message* msg = gems_create_message_control_set_login_name(cont->username);
+									gems_message* msg = NULL;
+									if(type == 1) msg = gems_create_message_teacher_service_profile_reply(cont->encrypted,cont->encrypted_length,cont->username);
+									else msg = gems_create_message_control_set_login_name(cont->username);
 									// Get connection
 									gems_connection* cn = (gems_connection*)(g_list_nth(data->clients,cnmbr)->data);
 									
 									if(gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN,cn,msg))
-										cem_add_to_log("Sent set username to first user in list",J_LOG_INFO);
-									else cem_add_to_log("Cannot send set username",J_LOG_INFO);
+										cem_add_to_log("Sent.",J_LOG_INFO);
+									else cem_add_to_log("Cannot send.",J_LOG_INFO);
 								
 									gems_clear_message(msg);
+									
 								}
 								
 								if(g_strcmp0(stdinput,"get") == 0)
@@ -689,6 +773,7 @@ int main(int argc,char* argv[])
 										gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN,(gems_connection*)iter->data,msg);
 									}
 								}
+								
 							}
 							break;
 					}
@@ -713,6 +798,10 @@ int main(int argc,char* argv[])
 		save_database(data->database);
 		clear_data_container(data);
 	}
+	jammo_cem_cleanup();
+	gems_security_clear_security();
+	configure_release_directories();
+	gems_free_data();
 	
 	return 0;
 }
